@@ -2,6 +2,7 @@
 
 import os
 import re
+import json
 import cccl
 import math
 import argparse
@@ -215,6 +216,12 @@ def iterate_case_dfs(args, callable):
 
     pattern = re.compile(args.R)
 
+    exact_values = {}
+    if args.args:
+        for value in args.args:
+            name, val = value.split('=')
+            exact_values[name] = val
+
     for algname in algnames:
         if not pattern.match(algname):
             continue
@@ -239,6 +246,10 @@ def iterate_case_dfs(args, callable):
                         target_df = target_df.drop(columns=['ctk', 'cccl', 'gpu'])
                         target_df = compute_speedup(target_df)
 
+                        for key in exact_values:
+                            if key in target_df.columns:
+                                target_df = target_df[target_df[key] == exact_values[key]]
+
                         for ct_point in ct_space(target_df):
                             point_str = ", ".join(["{}={}".format(k, ct_point[k]) for k in ct_point])
                             case_df = extract_complete_variants(extract_case(target_df, ct_point))
@@ -720,6 +731,28 @@ def file_exists(value):
     return value
 
 
+def case_offload(algname, ct_point_name, case_dfs):
+    for subbench in case_dfs:
+        df = case_dfs[subbench]
+        for rt_point in extract_rt_space(df):
+            point_df = df
+            for rt_kv in rt_point:
+                key, value = rt_kv.split('=')
+                point_df = point_df[point_df[key] == value]
+            point_name = ct_point_name + " " + " ".join(rt_point)
+            point_name = point_name.replace(',', '')
+            bench_name = "{}.{}-{}".format(algname, subbench, point_name)
+            bench_name = bench_name.replace(' ', '___')
+            bench_name = "".join(c if c.isalnum() else "_" for c in bench_name)
+            with open(bench_name + '.json', 'w') as f:
+                obj = json.loads(point_df.to_json(orient='records'))
+                json.dump(obj, f, indent=2)
+
+
+def offload(args):
+    iterate_case_dfs(args, case_offload)
+
+
 def parse_arguments():
     parser = argparse.ArgumentParser(description="Analyze benchmark results.")
     parser.add_argument(
@@ -742,6 +775,10 @@ def parse_arguments():
         '--variants-pdf', type=str, help="Show matching variants data.")
     parser.add_argument(
         '--variants-ratio', type=str, help="Show matching variants data.")
+    parser.add_argument('-a', '--args', action='append',
+                        type=str, help="Parameter in the format `Param=Value`.")
+    parser.add_argument(
+        '-o', '--offload', action=argparse.BooleanOptionalAction, help="Offload samples")
     return parser.parse_args()
 
 
@@ -771,6 +808,10 @@ def main():
     if args.variants_ratio:
         variants(args, 'ratio')
         return
+    
+    if args.offload:
+        offload(args)
+        return
 
     top(args)
 
