@@ -2,6 +2,8 @@
 
 source "$(dirname "$0")/build_common.sh"
 
+print_environment_details
+
 PRESET="libcudacxx-cpp${CXX_STANDARD}"
 CMAKE_OPTIONS=""
 
@@ -18,3 +20,5 @@ test_preset "libcudacxx (CTest)" ${CTEST_PRESET}
 source "./sccache_stats.sh" "start"
 test_preset "libcudacxx (lit)" ${LIT_PRESET}
 source "./sccache_stats.sh" "end"
+
+print_time_summary
