@@ -27,20 +27,28 @@
 
 #pragma once
 
+#include "cuda/std/detail/libcxx/include/__cccl/diagnostic.h"
 #include <metal.hpp>
 #include <type_traits>
 #include <cstdint>
 #include <tuple>
 
-#include <thrust/host_vector.h>
-#include <thrust/device_vector.h>
-
 #include <cub/util_compiler.cuh>
 #include "test_util_vec.h"
 
+#if __CUDACC_VER_MAJOR__ == 11
+_CCCL_NV_DIAG_SUPPRESS(177) // catch2 may contain unused variableds
+#endif // nvcc-11
+
+#include <c2h/device_policy.cuh>
+#include <c2h/utility.cuh>
+#include <c2h/vector.cuh>
+
 #include "catch2_main.cuh"
 #include "test_warning_suppression.cuh"
 
+#include <cuda/std/cmath>
+
 #ifndef VAR_IDX
 #define VAR_IDX 0
 #endif
@@ -75,19 +83,19 @@ using second = metal::second<P>;
 template <std::size_t start, std::size_t size, std::size_t stride = 1>
 using iota = metal::iota<metal::number<start>, metal::number<size>, metal::number<stride>>;
 
-} // namespace c2h 
+} // namespace c2h
 
 namespace detail
 {
   template <class T>
-  std::vector<T> to_vec(thrust::device_vector<T> const& vec)
+  std::vector<T> to_vec(c2h::device_vector<T> const& vec)
   {
-    thrust::host_vector<T> tmp = vec;
-    return std::vector<T>{tmp.begin(), tmp.end()};
+    c2h::host_vector<T> temp = vec;
+    return std::vector<T>{temp.begin(), temp.end()};
   }
 
   template <class T>
-  std::vector<T> to_vec(thrust::host_vector<T> const& vec)
+  std::vector<T> to_vec(c2h::host_vector<T> const& vec)
   {
     return std::vector<T>{vec.begin(), vec.end()};
   }
@@ -105,6 +113,80 @@ namespace detail
   REQUIRE_THAT(vec_ref, Catch::Approx(vec_out)); \
 }
 
+namespace detail
+{
+  // Returns true if values are equal, or both NaN:
+  struct equal_or_nans
+  {
+    template <typename T>
+    bool operator()(const T& a, const T& b) const
+    {
+      return (cuda::std::isnan(a) && cuda::std::isnan(b)) || a == b;
+    }
+  };
+
+  struct bitwise_equal
+  {
+    template <typename T>
+    bool operator()(const T&a, const T&b) const
+    {
+      using bits_t = typename cub::Traits<T>::UnsignedBits;
+      bits_t a_bits = c2h::bit_cast<bits_t>(a);
+      bits_t b_bits = c2h::bit_cast<bits_t>(b);
+      return a_bits == b_bits;
+    }
+  };
+
+  // Catch2 Matcher that calls `std::equal` with a default-constructable custom predicate
+  template <typename Range, typename Pred>
+  struct CustomEqualsRangeMatcher : Catch::MatcherBase<Range>
+  {
+    CustomEqualsRangeMatcher(Range const& range)
+        : range{range}
+    {}
+
+    bool match(Range const& other) const override
+    {
+      using std::begin;
+      using std::end;
+
+      return std::equal(begin(range), end(range), begin(other), Pred{});
+    }
+
+    std::string describe() const override
+    {
+      return "Equals: " + Catch::rangeToString(range);
+    }
+
+  private:
+    Range const& range;
+  };
+
+  template <typename Range>
+  auto NaNEqualsRange(const Range& range) -> CustomEqualsRangeMatcher<Range, equal_or_nans>
+  {
+    return CustomEqualsRangeMatcher<Range, equal_or_nans>(range);
+  }
+
+  template <typename Range>
+  auto BitwiseEqualsRange(const Range& range) -> CustomEqualsRangeMatcher<Range, bitwise_equal>
+  {
+    return CustomEqualsRangeMatcher<Range, bitwise_equal>(range);
+  }
+} // namespace detail
+
+#define REQUIRE_EQ_WITH_NAN_MATCHING(ref, out) { \
+  auto vec_ref = detail::to_vec(ref);  \
+  auto vec_out = detail::to_vec(out);  \
+  REQUIRE_THAT(vec_ref, detail::NaNEqualsRange(vec_out)); \
+}
+
+#define REQUIRE_BITWISE_EQ(ref, out) { \
+  auto vec_ref = detail::to_vec(ref);  \
+  auto vec_out = detail::to_vec(out);  \
+  REQUIRE_THAT(vec_ref, detail::NaNEqualsRange(vec_out)); \
+}
+
 #include <c2h/generators.cuh>
 #include <c2h/custom_type.cuh>
 
