@@ -27,8 +27,10 @@
 
 #pragma once
 
-#include <iostream>
+#include <cub/config.cuh>
+#include <cub/util_type.cuh>
 
+#include <iostream>
 
 /******************************************************************************
  * Console printing utilities
@@ -97,7 +99,7 @@ inline int CoutCast(signed char val) { return val; }
     {                                                       \
         T retval = make_##T(a.x + b.x);                     \
         return retval;                                      \
-    }                                                       
+    }
 
 
 
@@ -221,7 +223,7 @@ inline int CoutCast(signed char val) { return val; }
             a.y + b.y,                                      \
             a.z + b.z);                                     \
         return retval;                                      \
-    }                                                       
+    }
 
 
 /**
@@ -291,7 +293,7 @@ inline int CoutCast(signed char val) { return val; }
             a.z + b.z,                                      \
             a.w + b.w);                                     \
         return retval;                                      \
-    }                                                       
+    }
 
 /**
  * All vector overloads
@@ -464,4 +466,4 @@ CUB_VEC_TRAITS_OVERLOAD(uint, unsigned int)
 CUB_VEC_TRAITS_OVERLOAD(ulong, unsigned long)
 CUB_VEC_TRAITS_OVERLOAD(ulonglong, unsigned long long)
 CUB_VEC_TRAITS_OVERLOAD(float, float)
-CUB_VEC_TRAITS_OVERLOAD(double, double)
\ No newline at end of file
+CUB_VEC_TRAITS_OVERLOAD(double, double)
