@@ -14,14 +14,6 @@
 #include <__config>
 #endif //__cuda_std__
 
-#include "../__concepts/__concept_macros.h"
-#include "../__type_traits/enable_if.h"
-#include "../__type_traits/is_destructible.h"
-#include "../__type_traits/is_object.h"
-#include "../__type_traits/is_nothrow_destructible.h"
-#include "../__type_traits/void_t.h"
-#include "../__utility/declval.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -30,16 +22,24 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__concepts/__concept_macros.h"
+#include "../__type_traits/enable_if.h"
+#include "../__type_traits/is_destructible.h"
+#include "../__type_traits/is_object.h"
+#include "../__type_traits/is_nothrow_destructible.h"
+#include "../__type_traits/void_t.h"
+#include "../__utility/declval.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
-#if defined(_LIBCUDACXX_COMPILER_MSVC)
+#if defined(_CCCL_COMPILER_MSVC)
 
 template<class _Tp>
 _LIBCUDACXX_CONCEPT destructible = __is_nothrow_destructible(_Tp);
 
-#else // ^^^ _LIBCUDACXX_COMPILER_MSVC ^^^ / vvv !_LIBCUDACXX_COMPILER_MSVC vvv
+#else // ^^^ _CCCL_COMPILER_MSVC ^^^ / vvv !_CCCL_COMPILER_MSVC vvv
 
 template<class _Tp, class = void, class = void>
 _LIBCUDACXX_INLINE_VAR constexpr bool __destructible_impl = false;
@@ -47,11 +47,11 @@ _LIBCUDACXX_INLINE_VAR constexpr bool __destructible_impl = false;
 template<class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool __destructible_impl<_Tp,
                                    __enable_if_t<_LIBCUDACXX_TRAIT(is_object, _Tp)>,
-#if defined(_LIBCUDACXX_COMPILER_GCC)
+#if defined(_CCCL_COMPILER_GCC)
                                    __enable_if_t<_LIBCUDACXX_TRAIT(is_destructible, _Tp)>>
-#else // ^^^ defined(_LIBCUDACXX_COMPILER_GCC) ^^^ / vvv !_LIBCUDACXX_COMPILER_GCC vvv
+#else // ^^^ _CCCL_COMPILER_GCC ^^^ / vvv !_CCCL_COMPILER_GCC vvv
                                    __void_t<decltype(_CUDA_VSTD::declval<_Tp>().~_Tp())>>
-#endif // !_LIBCUDACXX_COMPILER_GCC
+#endif // !_CCCL_COMPILER_GCC
                                    = noexcept(_CUDA_VSTD::declval<_Tp>().~_Tp());
 
 template<class _Tp>
@@ -69,9 +69,9 @@ _LIBCUDACXX_INLINE_VAR constexpr bool __destructible<_Tp[_Nm]> = __destructible<
 template<class _Tp>
 _LIBCUDACXX_CONCEPT destructible = __destructible<_Tp>;
 
-#endif // !_LIBCUDACXX_COMPILER_MSVC
+#endif // !_CCCL_COMPILER_MSVC
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
