@@ -14,6 +14,14 @@
 #include <__config>
 #endif //__cuda_std__
 
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
+
 #include "../__concepts/__concept_macros.h"
 #include "../__concepts/assignable.h"
 #include "../__concepts/class_or_enum.h"
@@ -31,19 +39,11 @@
 #include "../__utility/forward.h"
 #include "../__utility/move.h"
 
-#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
-#  pragma GCC system_header
-#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
-#  pragma clang system_header
-#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
-#  pragma system_header
-#endif // no system header
-
 #if defined(_LIBCUDACXX_COMPILER_MSVC)
-_LIBCUDACXX_NV_DIAG_SUPPRESS(461) // nonstandard cast to array type ignored
+_CCCL_NV_DIAG_SUPPRESS(461) // nonstandard cast to array type ignored
 #endif // _LIBCUDACXX_COMPILER_MSVC
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_BEGIN_NAMESPACE_RANGES
 
@@ -54,7 +54,7 @@ _LIBCUDACXX_BEGIN_NAMESPACE_CPO(__swap)
   template<class _Tp>
   void swap(_Tp&, _Tp&) = delete;
 
-#if _LIBCUDACXX_STD_VER > 17
+#if _CCCL_STD_VER > 2017
   template<class _Tp, class _Up>
   concept __unqualified_swappable_with =
     (__class_or_enum<remove_cvref_t<_Tp>> || __class_or_enum<remove_cvref_t<_Up>>) &&
@@ -91,13 +91,13 @@ _LIBCUDACXX_BEGIN_NAMESPACE_CPO(__swap)
 
   template<class _Tp>
   _LIBCUDACXX_CONCEPT __exchangeable = _LIBCUDACXX_FRAGMENT(__exchangeable_, _Tp);
-#endif // _LIBCUDACXX_STD_VER < 20
+#endif // _CCCL_STD_VER < 2020
 
 
-#if _LIBCUDACXX_STD_VER > 17 && !defined(_LIBCUDACXX_COMPILER_NVHPC) // nvbug4051640
+#if _CCCL_STD_VER > 2017 && !defined(_CCCL_COMPILER_NVHPC) // nvbug4051640
   struct __fn;
 
-_LIBCUDACXX_NV_DIAG_SUPPRESS(2642)
+_CCCL_NV_DIAG_SUPPRESS(2642)
   template<class _Tp, class _Up, size_t _Size>
   concept __swappable_arrays =
     !__unqualified_swappable_with<_Tp(&)[_Size], _Up(&)[_Size]> &&
@@ -105,12 +105,12 @@ _LIBCUDACXX_NV_DIAG_SUPPRESS(2642)
     requires(_Tp(& __t)[_Size], _Up(& __u)[_Size], const __fn& __swap) {
       __swap(__t[0], __u[0]);
     };
-_LIBCUDACXX_NV_DIAG_DEFAULT(2642)
+_CCCL_NV_DIAG_DEFAULT(2642)
 
 #else
   template<class _Tp, class _Up, size_t _Size, class = void>
   _LIBCUDACXX_INLINE_VAR constexpr bool __swappable_arrays = false;
-#endif // _LIBCUDACXX_STD_VER < 20 || defined(_LIBCUDACXX_COMPILER_NVHPC)
+#endif // _CCCL_STD_VER < 2020 || defined(_CCCL_COMPILER_NVHPC)
 
 
   template<class _Tp, class _Up, class = void>
@@ -149,7 +149,7 @@ _LIBCUDACXX_NV_DIAG_DEFAULT(2642)
     }
   };
 
-#if _LIBCUDACXX_STD_VER < 20 || defined(_LIBCUDACXX_COMPILER_NVHPC)
+#if _CCCL_STD_VER < 2020 || defined(_CCCL_COMPILER_NVHPC)
   template<class _Tp, class _Up, class _Size>
   _LIBCUDACXX_CONCEPT_FRAGMENT(
     __swappable_arrays_,
@@ -162,7 +162,7 @@ _LIBCUDACXX_NV_DIAG_DEFAULT(2642)
   template<class _Tp, class _Up, size_t _Size>
   _LIBCUDACXX_INLINE_VAR constexpr bool __swappable_arrays<_Tp, _Up, _Size, void_t<type_identity_t<_Tp>>> =
     _LIBCUDACXX_FRAGMENT(__swappable_arrays_, _Tp, _Up, _CUDA_VSTD::integral_constant<size_t, _Size>);
-#endif // _LIBCUDACXX_STD_VER < 20 || defined(_LIBCUDACXX_COMPILER_NVHPC)
+#endif // _CCCL_STD_VER < 2020 || defined(_CCCL_COMPILER_NVHPC)
 
   template<class _Tp, class _Up>
   _LIBCUDACXX_INLINE_VAR constexpr bool __noexcept_swappable_arrays<_Tp, _Up, void_t<type_identity_t<_Tp>>> =
@@ -177,7 +177,7 @@ _LIBCUDACXX_END_NAMESPACE_RANGES
 
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 17
+#if _CCCL_STD_VER > 2017
 template<class _Tp>
 concept swappable = requires(_Tp& __a, _Tp& __b) { _CUDA_VRANGES::swap(__a, __b); };
 
@@ -218,10 +218,10 @@ _LIBCUDACXX_CONCEPT swappable_with = _LIBCUDACXX_FRAGMENT(__swappable_with_, _Tp
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 #if defined(_LIBCUDACXX_COMPILER_MSVC)
-_LIBCUDACXX_NV_DIAG_DEFAULT(461) // nonstandard cast to array type ignored
+_CCCL_NV_DIAG_DEFAULT(461) // nonstandard cast to array type ignored
 #endif // _LIBCUDACXX_COMPILER_MSVC
 
 
