@@ -34,7 +34,7 @@
 #include "../__cuda/ptx.h"           // cuda::ptx::*
 #endif // _CCCL_CUDA_COMPILER
 
-#if defined(_LIBCUDACXX_COMPILER_NVRTC)
+#if defined(_CCCL_COMPILER_NVRTC)
 #define _LIBCUDACXX_OFFSET_IS_ZERO(type, member) !(&(((type *)0)->member))
 #else
 #define _LIBCUDACXX_OFFSET_IS_ZERO(type, member) !offsetof(type, member)
@@ -667,7 +667,7 @@ _LIBCUDACXX_DEVICE inline async_contract_fulfillment memcpy_async_tx(
     // incorrectly classified as not trivially copyable. Remove this assertion to allow for their usage with
     // memcpy_async when compiling with GCC 4.8.
     // FIXME: remove the #if once GCC 4.8 is no longer supported.
-#if !defined(_LIBCUDACXX_COMPILER_GCC) || _GNUC_VER > 408
+#if !defined(_CCCL_COMPILER_GCC) || _GNUC_VER > 408
     static_assert(_CUDA_VSTD::is_trivially_copyable<_Tp>::value, "memcpy_async_tx requires a trivially copyable type");
 #endif
     static_assert(16 <= _Alignment, "mempcy_async_tx expects arguments to be at least 16 byte aligned.");
@@ -677,16 +677,11 @@ _LIBCUDACXX_DEVICE inline async_contract_fulfillment memcpy_async_tx(
     _LIBCUDACXX_DEBUG_ASSERT(__isGlobal(__src), "src must point to global memory.");
 
   NV_IF_ELSE_TARGET(NV_PROVIDES_SM_90,(
-    auto __bh = __cvta_generic_to_shared(barrier_native_handle(__b));
     if (__isShared(__dest) && __isGlobal(__src)) {
-        asm volatile(
-            "cp.async.bulk.shared::cluster.global.mbarrier::complete_tx::bytes [%0], [%1], %2, [%3];\n"
-            :
-            : "r"(static_cast<_CUDA_VSTD::uint32_t>(__cvta_generic_to_shared(__dest))),
-              "l"(static_cast<_CUDA_VSTD::uint64_t>(__cvta_generic_to_global(__src))),
-              "r"(static_cast<_CUDA_VSTD::uint32_t>(__size)),
-              "r"(static_cast<_CUDA_VSTD::uint32_t>(__bh))
-            : "memory");
+        _CUDA_VPTX::cp_async_bulk(
+            _CUDA_VPTX::space_cluster, _CUDA_VPTX::space_global,
+            __dest, __src, static_cast<uint32_t>(__size),
+            barrier_native_handle(__b));
     } else {
         // memcpy_async_tx only supports copying from global to shared
         // or from shared to remote cluster dsmem. To copy to remote
@@ -950,14 +945,9 @@ void __cp_async_bulk_shared_global(const _Group &__g, char * __dest, const char
     // https://docs.nvidia.com/cuda/parallel-thread-execution/index.html#data-movement-and-conversion-instructions-cp-async-bulk
   NV_IF_ELSE_TARGET(NV_PROVIDES_SM_90,(
     if (__g.thread_rank() == 0) {
-        asm volatile(
-            "cp.async.bulk.shared::cluster.global.mbarrier::complete_tx::bytes [%0], [%1], %2, [%3];\n"
-            :
-            : "r"(static_cast<_CUDA_VSTD::uint32_t>(__cvta_generic_to_shared(__dest))),
-              "l"(static_cast<_CUDA_VSTD::uint64_t>(__cvta_generic_to_global(__src))),
-              "r"(static_cast<_CUDA_VSTD::uint32_t>(__size)),
-              "r"(static_cast<_CUDA_VSTD::uint32_t>(__cvta_generic_to_shared(__bar_handle)))
-            : "memory");
+        _CUDA_VPTX::cp_async_bulk(
+            _CUDA_VPTX::space_cluster, _CUDA_VPTX::space_global,
+            __dest, __src, __size, __bar_handle);
     }
   ),(
     __cuda_ptx_cp_async_bulk_shared_global_is_not_supported_before_SM_90__();
@@ -973,9 +963,9 @@ void __cp_async_shared_global(char * __dest, const char * __src) {
 
     // If `if constexpr` is not available, this function gets instantiated even
     // if is not called. Do not static_assert in that case.
-#if _LIBCUDACXX_STD_VER >= 17
+#if _CCCL_STD_VER >= 2017
     static_assert(_Copy_size == 4 || _Copy_size == 8 || _Copy_size == 16, "cp.async.shared.global requires a copy size of 4, 8, or 16.");
-#endif // _LIBCUDACXX_STD_VER >= 17
+#endif // _CCCL_STD_VER >= 2017
 
   NV_IF_ELSE_TARGET(NV_PROVIDES_SM_80,(
     asm volatile(
@@ -1013,9 +1003,9 @@ inline __device__
 void __cp_async_shared_global_mechanism(_Group __g, char * __dest, const char * __src, _CUDA_VSTD::size_t __size) {
     // If `if constexpr` is not available, this function gets instantiated even
     // if is not called. Do not static_assert in that case.
-#if _LIBCUDACXX_STD_VER >= 17
+#if _CCCL_STD_VER >= 2017
     static_assert(4 <= _Alignment, "cp.async requires at least 4-byte alignment");
-#endif // _LIBCUDACXX_STD_VER >= 17
+#endif // _CCCL_STD_VER >= 2017
 
     // Maximal copy size is 16.
     constexpr int __copy_size = (_Alignment > 16) ? 16 : _Alignment;
@@ -1111,6 +1101,7 @@ __completion_mechanism __dispatch_memcpy_async_global_to_shared(_Group const & _
 #if __cccl_ptx_isa >= 800
     NV_IF_TARGET(NV_PROVIDES_SM_90, (
         const bool __can_use_complete_tx = __allowed_completions & uint32_t(__completion_mechanism::__mbarrier_complete_tx);
+        _LIBCUDACXX_UNUSED_VAR(__can_use_complete_tx);
         _LIBCUDACXX_DEBUG_ASSERT(__can_use_complete_tx == (nullptr != __bar_handle), "Pass non-null bar_handle if and only if can_use_complete_tx.");
         if _LIBCUDACXX_CONSTEXPR_AFTER_CXX14 (_Align >= 16) {
             if (__can_use_complete_tx && __isShared(__bar_handle)) {
