@@ -24,7 +24,7 @@
 #include "../__utility/move.h"
 #include "../exception"
 
-#if _LIBCUDACXX_STD_VER  > 11
+#if _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
@@ -74,6 +74,6 @@ private:
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 #endif // _LIBCUDACXX___EXPECTED_BAD_EXPECTED_ACCESS_H
