@@ -15,10 +15,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__functional/binary_function.h"
-#include "../__functional/unary_function.h"
-#include "../__utility/forward.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -27,11 +23,15 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__functional/binary_function.h"
+#include "../__functional/unary_function.h"
+#include "../__utility/forward.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 // Arithmetic operations
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -40,18 +40,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS plus
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x + __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(plus);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS plus<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -62,7 +62,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS plus<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -71,18 +71,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS minus
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x - __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(minus);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS minus<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -93,7 +93,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS minus<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -102,18 +102,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS multiplies
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x * __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(multiplies);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS multiplies<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -124,7 +124,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS multiplies<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -133,18 +133,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS divides
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x / __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(divides);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS divides<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -155,7 +155,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS divides<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -164,18 +164,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS modulus
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x % __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(modulus);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS modulus<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -186,7 +186,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS modulus<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -195,18 +195,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS negate
     : __unary_function<_Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x) const
         {return -__x;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(negate);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS negate<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _Tp>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_Tp&& __x) const
@@ -219,7 +219,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS negate<void>
 
 // Bitwise operations
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -228,18 +228,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_and
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x & __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(bit_and);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS bit_and<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -250,12 +250,12 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_and<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 struct _LIBCUDACXX_TEMPLATE_VIS bit_not
     : __unary_function<_Tp, _Tp>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x) const
         {return ~__x;}
@@ -265,7 +265,7 @@ _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(bit_not);
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS bit_not<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _Tp>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_Tp&& __x) const
@@ -276,7 +276,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_not<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -285,18 +285,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_or
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x | __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(bit_or);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS bit_or<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -307,7 +307,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_or<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -316,18 +316,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_xor
     : __binary_function<_Tp, _Tp, _Tp>
 {
     typedef _Tp __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     _Tp operator()(const _Tp& __x, const _Tp& __y) const
         {return __x ^ __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(bit_xor);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS bit_xor<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -340,7 +340,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS bit_xor<void>
 
 // Comparison operations
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -349,18 +349,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS equal_to
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x == __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(equal_to);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS equal_to<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -371,7 +371,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS equal_to<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -380,18 +380,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS not_equal_to
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x != __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(not_equal_to);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS not_equal_to<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -402,7 +402,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS not_equal_to<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -411,18 +411,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS less
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x < __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(less);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS less<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -433,7 +433,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS less<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -442,18 +442,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS less_equal
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x <= __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(less_equal);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS less_equal<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -464,7 +464,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS less_equal<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -473,18 +473,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS greater_equal
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x >= __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(greater_equal);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS greater_equal<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -495,7 +495,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS greater_equal<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -504,18 +504,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS greater
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x > __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(greater);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS greater<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -528,7 +528,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS greater<void>
 
 // Logical operations
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -537,18 +537,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS logical_and
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x && __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(logical_and);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS logical_and<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
@@ -559,7 +559,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS logical_and<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -568,18 +568,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS logical_not
     : __unary_function<_Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x) const
         {return !__x;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(logical_not);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS logical_not<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _Tp>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_Tp&& __x) const
@@ -590,7 +590,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS logical_not<void>
 };
 #endif
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Tp = void>
 #else
 template <class _Tp>
@@ -599,18 +599,18 @@ struct _LIBCUDACXX_TEMPLATE_VIS logical_or
     : __binary_function<_Tp, _Tp, bool>
 {
     typedef bool __result_type;  // used by valarray
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     bool operator()(const _Tp& __x, const _Tp& __y) const
         {return __x || __y;}
 };
 _LIBCUDACXX_CTAD_SUPPORTED_FOR_TYPE(logical_or);
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <>
 struct _LIBCUDACXX_TEMPLATE_VIS logical_or<void>
 {
-    _LIBCUDACXX_DISABLE_EXEC_CHECK
+    _CCCL_EXEC_CHECK_DISABLE
     template <class _T1, class _T2>
     _LIBCUDACXX_CONSTEXPR_AFTER_CXX11 _LIBCUDACXX_INLINE_VISIBILITY
     auto operator()(_T1&& __t, _T2&& __u) const
