@@ -14,9 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__functional/weak_result_type.h"
-#include "../__memory/addressof.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -25,6 +22,14 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__functional/invoke.h"
+#include "../__functional/weak_result_type.h"
+#include "../__memory/addressof.h"
+#include "../__type_traits/enable_if.h"
+#include "../__type_traits/remove_cvref.h"
+#include "../__utility/declval.h"
+#include "../__utility/forward.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <class _Tp>
@@ -57,12 +62,18 @@ public:
     template <class... _ArgTypes>
     _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX17
     typename __invoke_of<type&, _ArgTypes...>::type
-    operator() (_ArgTypes&&... __args) const {
+    operator() (_ArgTypes&&... __args) const
+#if _CCCL_STD_VER > 2011
+        // Since is_nothrow_invocable requires C++11 LWG3764 is not backported
+        // to earlier versions.
+        noexcept(_LIBCUDACXX_TRAIT(is_nothrow_invocable, _Tp&, _ArgTypes...))
+#endif
+    {
         return _CUDA_VSTD::__invoke(get(), _CUDA_VSTD::forward<_ArgTypes>(__args)...);
     }
 };
 
-#if _LIBCUDACXX_STD_VER > 14 && !defined(_LIBCUDACXX_HAS_NO_DEDUCTION_GUIDES)
+#if _CCCL_STD_VER > 2014 && !defined(_LIBCUDACXX_HAS_NO_DEDUCTION_GUIDES)
 template <class _Tp>
 _LIBCUDACXX_HOST_DEVICE reference_wrapper(_Tp&) -> reference_wrapper<_Tp>;
 #endif
