@@ -15,8 +15,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../cstddef"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -25,9 +23,11 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../cstddef"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_INLINE_VAR constexpr size_t dynamic_extent = static_cast<size_t>(-1);
 template <typename _Tp, size_t _Extent = dynamic_extent> class span;
