@@ -14,8 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__fwd/memory_resource.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -24,6 +22,8 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__fwd/memory_resource.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <class _CharT>
@@ -65,7 +65,7 @@ using u8string = basic_string<char8_t>;
 using u16string = basic_string<char16_t>;
 using u32string = basic_string<char32_t>;
 
-#if _LIBCUDACXX_STD_VER >= 17
+#if _CCCL_STD_VER >= 2017
 
 namespace pmr {
 template <class _CharT, class _Traits = char_traits<_CharT>>
@@ -86,7 +86,7 @@ using u32string = basic_string<char32_t>;
 
 } // namespace pmr
 
-#endif // _LIBCUDACXX_STD_VER >= 17
+#endif // _CCCL_STD_VER >= 2017
 
 // clang-format off
 template <class _CharT, class _Traits, class _Allocator>
@@ -99,7 +99,7 @@ class _LIBCUDACXX_PREFERRED_NAME(string)
 #endif
       _LIBCUDACXX_PREFERRED_NAME(u16string)
       _LIBCUDACXX_PREFERRED_NAME(u32string)
-#if _LIBCUDACXX_STD_VER >= 17
+#if _CCCL_STD_VER >= 2017
       _LIBCUDACXX_PREFERRED_NAME(pmr::string)
 #  ifndef _LIBCUDACXX_HAS_NO_WIDE_CHARACTERS
       _LIBCUDACXX_PREFERRED_NAME(pmr::wstring)
