@@ -15,10 +15,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__iterator/reverse_iterator.h"
-#include "../cstddef"
-#include "../initializer_list"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -27,9 +23,13 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__iterator/reverse_iterator.h"
+#include "../cstddef"
+#include "../initializer_list"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 template <class _Tp, size_t _Np>
 _LIBCUDACXX_INLINE_VISIBILITY _LIBCUDACXX_CONSTEXPR_AFTER_CXX14
@@ -101,7 +101,7 @@ auto crend(const _Cp& __c) -> decltype(_CUDA_VSTD::rend(__c))
     return _CUDA_VSTD::rend(__c);
 }
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
