@@ -15,10 +15,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/common_type.h"
-#include "../__type_traits/make_signed.h"
-#include "../cstddef"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -27,9 +23,13 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/common_type.h"
+#include "../__type_traits/make_signed.h"
+#include "../cstddef"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <class _Cont>
 _LIBCUDACXX_INLINE_VISIBILITY
 constexpr auto size(const _Cont& __c)
@@ -40,9 +40,9 @@ noexcept(noexcept(__c.size()))
 template <class _Tp, size_t _Sz>
 _LIBCUDACXX_INLINE_VISIBILITY
 constexpr size_t size(const _Tp (&)[_Sz]) noexcept { return _Sz; }
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
-#if _LIBCUDACXX_STD_VER > 17
+#if _CCCL_STD_VER > 2017
 template <class _Cont>
 _LIBCUDACXX_INLINE_VISIBILITY
 constexpr auto ssize(const _Cont& __c)
@@ -52,17 +52,13 @@ noexcept(noexcept(static_cast<common_type_t<ptrdiff_t, make_signed_t<decltype(__
 
 // GCC complains about the implicit conversion from ptrdiff_t to size_t in
 // the array bound.
-# if defined(_LIBCUDACXX_COMPILER_GCC)
-#   pragma GCC diagnostic push
-#   pragma GCC diagnostic ignored "-Wsign-conversion"
-# endif // _LIBCUDACXX_COMPILER_GCC
+_CCCL_DIAG_PUSH
+_CCCL_DIAG_SUPPRESS_GCC("-Wsign-conversion")
 template <class _Tp, ptrdiff_t _Sz>
 _LIBCUDACXX_INLINE_VISIBILITY
 constexpr ptrdiff_t ssize(const _Tp (&)[_Sz]) noexcept { return _Sz; }
-# if defined(_LIBCUDACXX_COMPILER_GCC)
-#   pragma GCC diagnostic pop
-# endif // _LIBCUDACXX_COMPILER_GCC
-#endif  // _LIBCUDACXX_STD_VER > 17
+_CCCL_DIAG_POP
+#endif  // _CCCL_STD_VER > 2017
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
