@@ -48,13 +48,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__mdspan/macros.h"
-#ifdef _LIBCUDACXX_HAS_NO_ATTRIBUTE_NO_UNIQUE_ADDRESS
-#include "../__mdspan/no_unique_address.h"
-#endif
-#include "../__type_traits/enable_if.h"
-#include "../__type_traits/is_empty.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -63,9 +56,16 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__mdspan/macros.h"
+#ifdef _LIBCUDACXX_HAS_NO_ATTRIBUTE_NO_UNIQUE_ADDRESS
+#include "../__mdspan/no_unique_address.h"
+#endif
+#include "../__type_traits/enable_if.h"
+#include "../__type_traits/is_empty.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 namespace __detail {
 
@@ -237,7 +237,7 @@ struct __compressed_pair<
 
 } // end namespace __detail
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
