@@ -48,10 +48,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__mdspan/macros.h"
-#include "../__type_traits/is_convertible.h"
-#include "../cstddef"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -60,9 +56,13 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__mdspan/macros.h"
+#include "../__type_traits/is_convertible.h"
+#include "../cstddef"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 template <class _ElementType>
 struct default_accessor {
@@ -96,7 +96,7 @@ struct default_accessor {
 
 };
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
