@@ -48,8 +48,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__mdspan/macros.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -58,15 +56,17 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__mdspan/macros.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 struct full_extent_t { explicit full_extent_t() = default; };
 
 _LIBCUDACXX_INLINE_VAR constexpr auto full_extent = full_extent_t{ };
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
