@@ -48,6 +48,14 @@
 #include <__config>
 #endif // __cuda_std__
 
+#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
+#  pragma GCC system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
+#  pragma clang system_header
+#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
+#  pragma system_header
+#endif // no system header
+
 #include "../__mdspan/compressed_pair.h"
 #include "../__mdspan/extents.h"
 #include "../__mdspan/macros.h"
@@ -62,7 +70,6 @@
 #include "../__type_traits/remove_const.h"
 #include "../__utility/integer_sequence.h"
 #include "../__utility/move.h"
-#include "../algorithm"
 #include "../array"
 #if __MDSPAN_USE_CONCEPTS && __MDSPAN_HAS_CXX_20
 #include "../concepts"
@@ -70,17 +77,9 @@
 #include "../numeric"
 #include "../span"
 
-#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
-#  pragma GCC system_header
-#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
-#  pragma clang system_header
-#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
-#  pragma system_header
-#endif // no system header
-
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 struct layout_left {
   template<class _Extents>
@@ -552,7 +551,7 @@ struct layout_stride {
   };
 };
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
