@@ -49,12 +49,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__mdspan/config.h"
-#include "../__type_traits/enable_if.h"
-#include "../__type_traits/is_void.h"
-#include "../__type_traits/remove_reference.h"
-#include "../__utility/declval.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -63,7 +57,13 @@
 #  pragma system_header
 #endif // no system header
 
-#if _LIBCUDACXX_STD_VER > 11
+#include "../__mdspan/config.h"
+#include "../__type_traits/enable_if.h"
+#include "../__type_traits/is_void.h"
+#include "../__type_traits/remove_reference.h"
+#include "../__utility/declval.h"
+
+#if _CCCL_STD_VER > 2011
 
 #ifndef __MDSPAN_FORCE_INLINE_FUNCTION
 #  ifdef __MDSPAN_COMPILER_MSVC // Microsoft compilers
@@ -630,7 +630,7 @@ _LIBCUDACXX_END_NAMESPACE_STD
 // </editor-fold> end Pre-C++14 constexpr }}}1
 //==============================================================================
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 #ifndef _LIBCUDACXX_NO_EXCEPTIONS
 #define _LIBCUDACXX_THROW_RUNTIME_ERROR(_COND, _MESSAGE) \
