@@ -48,12 +48,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__mdspan/macros.h"
-#include "../__type_traits/enable_if.h"
-#include "../__type_traits/is_empty.h"
-#include "../__type_traits/is_trivially_destructible.h"
-#include "../__utility/move.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -62,9 +56,15 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__mdspan/macros.h"
+#include "../__type_traits/enable_if.h"
+#include "../__type_traits/is_empty.h"
+#include "../__type_traits/is_trivially_destructible.h"
+#include "../__utility/move.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 namespace __detail {
 
@@ -142,7 +142,7 @@ struct __no_unique_address_emulation<
 
 } // end namespace __detail
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
