@@ -13,12 +13,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/conditional.h"
-#include "../__type_traits/integral_constant.h"
-#include "../__type_traits/nat.h"
-#include "../__type_traits/type_list.h"
-#include "../cstddef"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -27,6 +21,12 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/conditional.h"
+#include "../__type_traits/integral_constant.h"
+#include "../__type_traits/nat.h"
+#include "../__type_traits/type_list.h"
+#include "../cstddef"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 template <class _Tp>
@@ -100,7 +100,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS aligned_storage
     };
 };
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 template <size_t _Len, size_t _Align = __find_max_align<__all_types, _Len>::value>
     using aligned_storage_t = typename aligned_storage<_Len, _Align>::type;
 #endif
