@@ -14,8 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/integral_constant.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -24,9 +22,11 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/integral_constant.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11 && defined(_LIBCUDACXX_IS_AGGREGATE)
+#if _CCCL_STD_VER > 2011 && defined(_LIBCUDACXX_IS_AGGREGATE)
 
 template <class _Tp> struct _LIBCUDACXX_TEMPLATE_VIS
 is_aggregate : public integral_constant<bool, _LIBCUDACXX_IS_AGGREGATE(_Tp)> {};
@@ -36,7 +36,7 @@ template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_aggregate_v = _LIBCUDACXX_IS_AGGREGATE(_Tp);
 #endif
 
-#endif // _LIBCUDACXX_STD_VER > 11 && defined(_LIBCUDACXX_IS_AGGREGATE)
+#endif // _CCCL_STD_VER > 2011 && defined(_LIBCUDACXX_IS_AGGREGATE)
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
