@@ -14,9 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/integral_constant.h"
-#include "../__type_traits/is_union.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -25,6 +22,9 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/integral_constant.h"
+#include "../__type_traits/is_union.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 struct __two {char __lx[2];};
@@ -34,7 +34,7 @@ struct __two {char __lx[2];};
 template <class _Tp> struct _LIBCUDACXX_TEMPLATE_VIS is_class
     : public integral_constant<bool, _LIBCUDACXX_IS_CLASS(_Tp)> {};
 
-#if _LIBCUDACXX_STD_VER > 11 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
+#if _CCCL_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
 template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_class_v = _LIBCUDACXX_IS_CLASS(_Tp);
 #endif
@@ -50,7 +50,7 @@ template <class _Tp> _LIBCUDACXX_HOST_DEVICE __two __test(...);
 template <class _Tp> struct _LIBCUDACXX_TEMPLATE_VIS is_class
     : public integral_constant<bool, sizeof(__is_class_imp::__test<_Tp>(0)) == 1 && !is_union<_Tp>::value> {};
 
-#if _LIBCUDACXX_STD_VER > 11 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
+#if _CCCL_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
 template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_class_v = is_class<_Tp>::value;
 #endif
