@@ -14,14 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/integral_constant.h"
-#include "../__type_traits/is_destructible.h"
-#include "../__type_traits/is_reference.h"
-#include "../__type_traits/is_scalar.h"
-#include "../__type_traits/remove_all_extents.h"
-#include "../__utility/declval.h"
-#include "../cstddef"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -30,6 +22,14 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/integral_constant.h"
+#include "../__type_traits/is_destructible.h"
+#include "../__type_traits/is_reference.h"
+#include "../__type_traits/is_scalar.h"
+#include "../__type_traits/remove_all_extents.h"
+#include "../__utility/declval.h"
+#include "../cstddef"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 // is_nothrow_destructible
@@ -90,7 +90,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS is_nothrow_destructible<_Tp[]>
 
 #endif // defined(_LIBCUDACXX_IS_NOTHROW_DESTRUCTIBLE) && !defined(_LIBCUDACXX_USE_IS_NOTHROW_DESTRUCTIBLE_FALLBACK)
 
-#if _LIBCUDACXX_STD_VER > 11 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
+#if _CCCL_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
 template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_nothrow_destructible_v
     = is_nothrow_destructible<_Tp>::value;
