@@ -14,10 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/add_const.h"
-#include "../__type_traits/add_lvalue_reference.h"
-#include "../__type_traits/is_trivially_constructible.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -26,6 +22,10 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/add_const.h"
+#include "../__type_traits/add_lvalue_reference.h"
+#include "../__type_traits/is_trivially_constructible.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 #if defined(_LIBCUDACXX_IS_TRIVIALLY_CONSTRUCTIBLE) && !defined(_LIBCUDACXX_USE_IS_TRIVIALLY_CONSTRUCTIBLE_FALLBACK)
@@ -36,7 +36,7 @@ struct _LIBCUDACXX_TEMPLATE_VIS is_trivially_copy_constructible
         _LIBCUDACXX_IS_TRIVIALLY_CONSTRUCTIBLE(_Tp, __add_lvalue_reference_t<typename add_const<_Tp>::type>)>
     {};
 
-#if _LIBCUDACXX_STD_VER > 11 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
+#if _CCCL_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
 template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_trivially_copy_constructible_v =
     _LIBCUDACXX_IS_TRIVIALLY_CONSTRUCTIBLE(_Tp, __add_lvalue_reference_t<typename add_const<_Tp>::type>);
@@ -48,7 +48,7 @@ template <class _Tp> struct _LIBCUDACXX_TEMPLATE_VIS is_trivially_copy_construct
     : public is_trivially_constructible<_Tp, __add_lvalue_reference_t<typename add_const<_Tp>::type>>
     {};
 
-#if _LIBCUDACXX_STD_VER > 11 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
+#if _CCCL_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_VARIABLE_TEMPLATES)
 template <class _Tp>
 _LIBCUDACXX_INLINE_VAR constexpr bool is_trivially_copy_constructible_v = is_trivially_copy_constructible<_Tp>::value;
 #endif
