@@ -15,8 +15,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/decay.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -25,6 +23,12 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/decay.h"
+
+#if _CCCL_STD_VER < 2020 && defined(_CCCL_COMPILER_MSVC)
+#define _LIBCUDACXX_AUTO_CAST(expr) (_CUDA_VSTD::decay_t<decltype((expr))>)(expr)
+#else
 #define _LIBCUDACXX_AUTO_CAST(expr) static_cast<_CUDA_VSTD::decay_t<decltype((expr))>>(expr)
+#endif
 
 #endif // _LIBCUDACXX___UTILITY_AUTO_CAST_H
