@@ -26,12 +26,12 @@ _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
 // Suppress deprecation notice for volatile-qualified return type resulting
 // from volatile-qualified types _Tp.
-_LIBCUDACXX_SUPPRESS_DEPRECATED_PUSH
+_CCCL_SUPPRESS_DEPRECATED_PUSH
 template <class _Tp>
 _LIBCUDACXX_INLINE_VISIBILITY _Tp&& __declval(int);
 template <class _Tp>
 _LIBCUDACXX_INLINE_VISIBILITY _Tp __declval(long);
-_LIBCUDACXX_SUPPRESS_DEPRECATED_POP
+_CCCL_SUPPRESS_DEPRECATED_POP
 
 template <class _Tp>
 _LIBCUDACXX_INLINE_VISIBILITY decltype(_CUDA_VSTD::__declval<_Tp>(0)) declval() noexcept;
