@@ -14,10 +14,6 @@
 #include <__config>
 #endif // __cuda_std__
 
-#include "../__type_traits/is_reference.h"
-#include "../__type_traits/remove_reference.h"
-#include "../__type_traits/remove_cvref.h"
-
 #if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
 #  pragma GCC system_header
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
@@ -26,9 +22,13 @@
 #  pragma system_header
 #endif // no system header
 
+#include "../__type_traits/is_reference.h"
+#include "../__type_traits/remove_reference.h"
+#include "../__type_traits/remove_cvref.h"
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-#if _LIBCUDACXX_STD_VER > 11
+#if _CCCL_STD_VER > 2011
 
 struct _LIBCUDACXX_TYPE_VIS in_place_t {
     explicit in_place_t() = default;
@@ -61,7 +61,7 @@ template <size_t _Idx> struct __is_inplace_index_imp<in_place_index_t<_Idx>> : t
 template <class _Tp>
 using __is_inplace_index = __is_inplace_index_imp<__remove_cvref_t<_Tp>>;
 
-#endif // _LIBCUDACXX_STD_VER > 11
+#endif // _CCCL_STD_VER > 2011
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
