@@ -20,6 +20,15 @@
 #include "test_macros.h"
 #include "test_iterators.h"
 
+#if TEST_STD_VER > 2014
+struct NoDefaultCtr : forward_iterator<int*> {
+  NoDefaultCtr() = delete;
+};
+
+static_assert( cuda::std::is_default_constructible_v<cuda::std::move_iterator<forward_iterator<int*>>>, "");
+static_assert(!cuda::std::is_default_constructible_v<cuda::std::move_iterator<NoDefaultCtr>>, "");
+#endif // TEST_STD_VER > 2014
+
 template <class It>
 __host__ __device__
 void test() {
@@ -34,7 +43,7 @@ int main(int, char**) {
   test<random_access_iterator<char*> >();
   test<char*>();
 
-#if TEST_STD_VER > 14
+#if TEST_STD_VER > 2011
   {
     constexpr cuda::std::move_iterator<const char *> it;
     unused(it);
