@@ -39,6 +39,13 @@ int main(int, char**)
     test<double>();
 // CUDA treats long double as double
 //  test<long double>();
+// These specializations didn't exist at the time of ABI v3:
+#ifdef _LIBCUDACXX_HAS_NVFP16
+//    test<__half>();
+#endif
+#ifdef _LIBCUDACXX_HAS_NVBF16
+//    test<__nv_bfloat16>();
+#endif
 
   return 0;
 }
