@@ -486,11 +486,13 @@ void throws_in_constructor_test()
 __host__ __device__
 void call_operator_sfinae_test() {
 #ifndef TEST_COMPILER_ICC
+#if !defined(TEST_COMPILER_MSVC_2017)
     { // wrong number of arguments
         using T = decltype(cuda::std::not_fn(returns_true));
         static_assert(cuda::std::is_invocable<T>::value, ""); // callable only with no args
         static_assert(!cuda::std::is_invocable<T, bool>::value, "");
     }
+#endif // !TEST_COMPILER_MSVC_2017
     { // violates const correctness (member function pointer)
         using T = decltype(cuda::std::not_fn(&MemFunCallable::return_value_nc));
         static_assert(cuda::std::is_invocable<T, MemFunCallable&>::value, "");
@@ -627,7 +629,7 @@ void call_operator_noexcept_test()
         auto ret = cuda::std::not_fn(value);
         (void)ret;
         LIBCPP_STATIC_ASSERT(noexcept(!_CUDA_VSTD::__invoke(value)), "");
-#if TEST_STD_VER > 14
+#if TEST_STD_VER > 2014
         static_assert(noexcept(!cuda::std::invoke(value)), "");
 #endif
 // TODO: nvcc gets this wrong, investigate
