@@ -26,19 +26,19 @@ int main(int, char**)
     using weekday      = cuda::std::chrono::weekday;
     using weekday_last = cuda::std::chrono::weekday_last;
 
-    AssertComparisons2AreNoexcept<weekday_last>();
-    AssertComparisons2ReturnBool<weekday_last>();
+    AssertEqualityAreNoexcept<weekday_last>();
+    AssertEqualityReturnBool<weekday_last>();
 
-    static_assert(testComparisons2Values<weekday_last>(weekday{0}, weekday{0}), "");
-    static_assert(testComparisons2Values<weekday_last>(weekday{0}, weekday{1}), "");
+    static_assert(testEqualityValues<weekday_last>(weekday{0}, weekday{0}), "");
+    static_assert(testEqualityValues<weekday_last>(weekday{0}, weekday{1}), "");
 
 //  Some 'ok' values as well
-    static_assert(testComparisons2Values<weekday_last>(weekday{2}, weekday{2}), "");
-    static_assert(testComparisons2Values<weekday_last>(weekday{2}, weekday{3}), "");
+    static_assert(testEqualityValues<weekday_last>(weekday{2}, weekday{2}), "");
+    static_assert(testEqualityValues<weekday_last>(weekday{2}, weekday{3}), "");
 
     for (unsigned i = 0; i < 6; ++i)
         for (unsigned j = 0; j < 6; ++j)
-            assert(testComparisons2Values<weekday_last>(weekday{i}, weekday{j}));
+            assert(testEqualityValues<weekday_last>(weekday{i}, weekday{j}));
 
   return 0;
 }
