@@ -25,19 +25,19 @@ int main(int, char**)
 {
     using weekday = cuda::std::chrono::weekday;
 
-    AssertComparisons2AreNoexcept<weekday>();
-    AssertComparisons2ReturnBool<weekday>();
+    AssertEqualityAreNoexcept<weekday>();
+    AssertEqualityReturnBool<weekday>();
 
-    static_assert(testComparisons2Values<weekday>(0U ,0U), "");
-    static_assert(testComparisons2Values<weekday>(0U, 1U), "");
+    static_assert(testEqualityValues<weekday>(0U ,0U), "");
+    static_assert(testEqualityValues<weekday>(0U, 1U), "");
 
 //  Some 'ok' values as well
-    static_assert(testComparisons2Values<weekday>(5U, 5U), "");
-    static_assert(testComparisons2Values<weekday>(5U, 2U), "");
+    static_assert(testEqualityValues<weekday>(5U, 5U), "");
+    static_assert(testEqualityValues<weekday>(5U, 2U), "");
 
     for (unsigned i = 0; i < 6; ++i)
         for (unsigned j = 0; j < 6; ++j)
-            assert(testComparisons2Values<weekday>(i, j));
+            assert(testEqualityValues<weekday>(i, j));
 
   return 0;
 }
