@@ -31,7 +31,7 @@
 #endif // no system header
 #include <thrust/detail/cpp14_required.h>
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 
 #include <thrust/detail/static_assert.h>
 #include <thrust/detail/select_system.h>
@@ -57,7 +57,7 @@ template <
   typename DerivedPolicy
 , typename ForwardIt, typename Sentinel, typename StrictWeakOrdering
 >
-__host__
+_CCCL_HOST
 event<DerivedPolicy>
 async_stable_sort(
   thrust::execution_policy<DerivedPolicy>&
@@ -84,7 +84,7 @@ struct stable_sort_fn final
     typename DerivedPolicy
   , typename ForwardIt, typename Sentinel, typename StrictWeakOrdering
   >
-  __host__
+  _CCCL_HOST
   static auto call(
     thrust::detail::execution_policy_base<DerivedPolicy> const& exec
   , ForwardIt&& first, Sentinel&& last
@@ -103,7 +103,7 @@ struct stable_sort_fn final
     typename DerivedPolicy
   , typename ForwardIt, typename Sentinel
   >
-  __host__
+  _CCCL_HOST
   static auto call(
     thrust::detail::execution_policy_base<DerivedPolicy> const& exec
   , ForwardIt&& first, Sentinel&& last
@@ -120,7 +120,7 @@ struct stable_sort_fn final
   )
 
   template <typename ForwardIt, typename Sentinel, typename StrictWeakOrdering>
-  __host__
+  _CCCL_HOST
   static auto call(ForwardIt&& first, Sentinel&& last, StrictWeakOrdering&& comp)
   THRUST_RETURNS(
     stable_sort_fn::call(
@@ -133,7 +133,7 @@ struct stable_sort_fn final
   )
 
   template <typename ForwardIt, typename Sentinel>
-  __host__
+  _CCCL_HOST
   static auto call(ForwardIt&& first, Sentinel&& last)
   THRUST_RETURNS(
     stable_sort_fn::call(
@@ -145,7 +145,7 @@ struct stable_sort_fn final
   )
 
   template <typename... Args>
-  THRUST_NODISCARD __host__
+  THRUST_NODISCARD _CCCL_HOST
   auto operator()(Args&&... args) const
   THRUST_RETURNS(
     call(THRUST_FWD(args)...)
@@ -163,7 +163,7 @@ template <
   typename DerivedPolicy
 , typename ForwardIt, typename Sentinel, typename StrictWeakOrdering
 >
-__host__
+_CCCL_HOST
 event<DerivedPolicy>
 async_sort(
   thrust::execution_policy<DerivedPolicy>& exec
@@ -189,7 +189,7 @@ struct sort_fn final
     typename DerivedPolicy
   , typename ForwardIt, typename Sentinel, typename StrictWeakOrdering
   >
-  __host__
+  _CCCL_HOST
   static auto call(
     thrust::detail::execution_policy_base<DerivedPolicy> const& exec
   , ForwardIt&& first, Sentinel&& last
@@ -208,7 +208,7 @@ struct sort_fn final
     typename DerivedPolicy
   , typename ForwardIt, typename Sentinel
   >
-  __host__
+  _CCCL_HOST
   static auto call3(
     thrust::detail::execution_policy_base<DerivedPolicy> const& exec
   , ForwardIt&& first, Sentinel&& last
@@ -225,7 +225,7 @@ struct sort_fn final
   )
 
   template <typename ForwardIt, typename Sentinel, typename StrictWeakOrdering>
-  __host__
+  _CCCL_HOST
   static auto call3(ForwardIt&& first, Sentinel&& last,
                     StrictWeakOrdering&& comp,
                     thrust::false_type)
@@ -243,7 +243,7 @@ struct sort_fn final
   // if T1 is an execution_policy by using SFINAE. Switching to a static
   // dispatch pattern to prevent this.
   template <typename T1, typename T2, typename T3>
-  __host__
+  _CCCL_HOST
   static auto call(T1&& t1, T2&& t2, T3&& t3)
   THRUST_RETURNS(
     sort_fn::call3(THRUST_FWD(t1), THRUST_FWD(t2), THRUST_FWD(t3),
@@ -251,7 +251,7 @@ struct sort_fn final
   )
 
   template <typename ForwardIt, typename Sentinel>
-  __host__
+  _CCCL_HOST
   static auto call(ForwardIt&& first, Sentinel&& last)
   THRUST_RETURNS(
     sort_fn::call(
@@ -266,7 +266,7 @@ struct sort_fn final
   )
 
   template <typename... Args>
-  THRUST_NODISCARD __host__
+  THRUST_NODISCARD _CCCL_HOST
   auto operator()(Args&&... args) const
   THRUST_RETURNS(
     call(THRUST_FWD(args)...)
