@@ -35,6 +35,7 @@
 #include <complex>
 #include <sstream>
 #include <thrust/detail/type_traits.h>
+#include <thrust/type_traits/is_trivially_relocatable.h>
 
 #if THRUST_CPP_DIALECT >= 2011
 #  define THRUST_STD_COMPLEX_REAL(z) \
@@ -175,7 +176,7 @@ public:
    *
    *  \param re The real part of the number.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex(const T& re);
 
   /*! Construct a complex number from its real and imaginary parts.
@@ -183,7 +184,7 @@ public:
    *  \param re The real part of the number.
    *  \param im The imaginary part of the number.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex(const T& re, const T& im);
 
 #if THRUST_CPP_DIALECT >= 2011
@@ -200,7 +201,7 @@ public:
 #else
   /*! Default construct a complex number.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex();
 
   /*! This copy constructor copies from a \p complex with a type that is
@@ -208,7 +209,7 @@ public:
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex(const complex<T>& z);
 #endif
 
@@ -220,7 +221,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex(const complex<U>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
@@ -251,7 +252,7 @@ public:
    *
    *  \param re The real part of the number.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex& operator=(const T& re);
 
 #if THRUST_CPP_DIALECT >= 2011
@@ -267,7 +268,7 @@ public:
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex& operator=(const complex<T>& z);
 #endif
 
@@ -279,7 +280,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex& operator=(const complex<U>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
@@ -312,7 +313,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator+=(const complex<U>& z);
 
   /*! Subtracts a \p complex from this \p complex and assigns the result to
@@ -323,7 +324,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator-=(const complex<U>& z);
 
   /*! Multiplies this \p complex by another \p complex and assigns the result
@@ -334,7 +335,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator*=(const complex<U>& z);
 
   /*! Divides this \p complex by another \p complex and assigns the result to
@@ -345,7 +346,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator/=(const complex<U>& z);
 
   /*! Adds a scalar to this \p complex and assigns the result to this
@@ -356,7 +357,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator+=(const U& z);
 
   /*! Subtracts a scalar from this \p complex and assigns the result to
@@ -367,7 +368,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator-=(const U& z);
 
   /*! Multiplies this \p complex by a scalar and assigns the result
@@ -378,7 +379,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator*=(const U& z);
 
   /*! Divides this \p complex by a scalar and assigns the result to
@@ -389,7 +390,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   complex<T>& operator/=(const U& z);
 
 
@@ -401,22 +402,22 @@ public:
 
   /*! Returns the real part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   T real() const volatile { return data.x; }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   T imag() const volatile { return data.y; }
 
   /*! Returns the real part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   T real() const { return data.x; }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   T imag() const { return data.y; }
 
 
@@ -430,28 +431,28 @@ public:
    *
    *  \param re The new real part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   void real(T re) volatile { data.x = re; }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.e
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   void imag(T im) volatile { data.y = im; }
 
   /*! Sets the real part of this \p complex.
    *
    *  \param re The new real part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   void real(T re) { data.x = re; }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   void imag(T im) { data.y = im; }
 
 
@@ -475,7 +476,7 @@ private:
  *  \param z The \p complex from which to calculate the absolute value.
  */
 template<typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 T abs(const complex<T>& z);
 
 /*! Returns the phase angle (also known as argument) in radians of a \p complex.
@@ -483,7 +484,7 @@ T abs(const complex<T>& z);
  *  \param z The \p complex from which to calculate the phase angle.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 T arg(const complex<T>& z);
 
 /*! Returns the square of the magnitude of a \p complex.
@@ -491,7 +492,7 @@ T arg(const complex<T>& z);
  *  \param z The \p complex from which to calculate the norm.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 T norm(const complex<T>& z);
 
 /*! Returns the complex conjugate of a \p complex.
@@ -499,7 +500,7 @@ T norm(const complex<T>& z);
  *  \param z The \p complex from which to calculate the complex conjugate.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> conj(const complex<T>& z);
 
 /*! Returns a \p complex with the specified magnitude and phase.
@@ -508,7 +509,7 @@ complex<T> conj(const complex<T>& z);
  *  \param theta The phase of the returned \p complex in radians.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 polar(const T0& m, const T1& theta = T1());
 
@@ -520,7 +521,7 @@ polar(const T0& m, const T1& theta = T1());
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> proj(const T& z);
 
 
@@ -536,7 +537,7 @@ complex<T> proj(const T& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const complex<T0>& x, const complex<T1>& y);
 
@@ -549,7 +550,7 @@ operator+(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const complex<T0>& x, const T1& y);
 
@@ -562,7 +563,7 @@ operator+(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const T0& x, const complex<T1>& y);
 
@@ -575,7 +576,7 @@ operator+(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const complex<T0>& x, const complex<T1>& y);
 
@@ -588,7 +589,7 @@ operator-(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const complex<T0>& x, const T1& y);
 
@@ -601,7 +602,7 @@ operator-(const complex<T0>& x, const T1& y);
  *  \param y The \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const T0& x, const complex<T1>& y);
 
@@ -614,7 +615,7 @@ operator-(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const complex<T0>& x, const complex<T1>& y);
 
@@ -624,7 +625,7 @@ operator*(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const complex<T0>& x, const T1& y);
 
@@ -637,7 +638,7 @@ operator*(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const T0& x, const complex<T1>& y);
 
@@ -650,7 +651,7 @@ operator*(const T0& x, const complex<T1>& y);
  *  \param y The denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const complex<T0>& x, const complex<T1>& y);
 
@@ -663,7 +664,7 @@ operator/(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const complex<T0>& x, const T1& y);
 
@@ -676,7 +677,7 @@ operator/(const complex<T0>& x, const T1& y);
  *  \param y The complex denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const T0& x, const complex<T1>& y);
 
@@ -689,7 +690,7 @@ operator/(const T0& x, const complex<T1>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T>
 operator+(const complex<T>& y);
 
@@ -699,7 +700,7 @@ operator+(const complex<T>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T>
 operator-(const complex<T>& y);
 
@@ -712,7 +713,7 @@ operator-(const complex<T>& y);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> exp(const complex<T>& z);
 
 /*! Returns the complex natural logarithm of a \p complex number.
@@ -720,7 +721,7 @@ complex<T> exp(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> log(const complex<T>& z);
 
 /*! Returns the complex base 10 logarithm of a \p complex number.
@@ -728,7 +729,7 @@ complex<T> log(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> log10(const complex<T>& z);
 
 
@@ -744,7 +745,7 @@ complex<T> log10(const complex<T>& z);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const complex<T0>& x, const complex<T1>& y);
 
@@ -757,7 +758,7 @@ pow(const complex<T0>& x, const complex<T1>& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const complex<T0>& x, const T1& y);
 
@@ -770,7 +771,7 @@ pow(const complex<T0>& x, const T1& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const T0& x, const complex<T1>& y);
 
@@ -779,7 +780,7 @@ pow(const T0& x, const complex<T1>& y);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> sqrt(const complex<T>& z);
 
 
@@ -790,7 +791,7 @@ complex<T> sqrt(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> cos(const complex<T>& z);
 
 /*! Returns the complex sine of a \p complex number.
@@ -798,7 +799,7 @@ complex<T> cos(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> sin(const complex<T>& z);
 
 /*! Returns the complex tangent of a \p complex number.
@@ -806,7 +807,7 @@ complex<T> sin(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> tan(const complex<T>& z);
 
 
@@ -818,7 +819,7 @@ complex<T> tan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> cosh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic sine of a \p complex number.
@@ -826,7 +827,7 @@ complex<T> cosh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> sinh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic tangent of a \p complex number.
@@ -834,7 +835,7 @@ complex<T> sinh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> tanh(const complex<T>& z);
 
 
@@ -849,7 +850,7 @@ complex<T> tanh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> acos(const complex<T>& z);
 
 /*! Returns the complex arc sine of a \p complex number.
@@ -860,7 +861,7 @@ complex<T> acos(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> asin(const complex<T>& z);
 
 /*! Returns the complex arc tangent of a \p complex number.
@@ -871,7 +872,7 @@ complex<T> asin(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> atan(const complex<T>& z);
 
 
@@ -886,7 +887,7 @@ complex<T> atan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> acosh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic sine of a \p complex number.
@@ -897,7 +898,7 @@ complex<T> acosh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> asinh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic tangent of a \p complex number.
@@ -908,7 +909,7 @@ complex<T> asinh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 complex<T> atanh(const complex<T>& z);
 
 
@@ -951,7 +952,7 @@ operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator==(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
@@ -979,7 +980,7 @@ bool operator==(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator==(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
@@ -989,7 +990,7 @@ bool operator==(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator==(const complex<T0>& x, const T1& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
@@ -998,7 +999,7 @@ bool operator==(const complex<T0>& x, const T1& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator!=(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
@@ -1026,7 +1027,7 @@ bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator!=(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
@@ -1036,7 +1037,7 @@ bool operator!=(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator!=(const complex<T0>& x, const T1& y);
 
 THRUST_NAMESPACE_END
