@@ -88,7 +88,7 @@ THRUST_NAMESPACE_BEGIN
  *  \endcode
  */
 template<typename DerivedPolicy, typename InputIterator, typename OutputIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                       InputIterator first,
                       InputIterator last,
@@ -141,7 +141,7 @@ __host__ __device__
  *  \see thrust::copy
  */
 template<typename DerivedPolicy, typename InputIterator, typename Size, typename OutputIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator copy_n(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                         InputIterator first,
                         Size n,
@@ -304,7 +304,7 @@ template<typename InputIterator, typename Size, typename OutputIterator>
  *  \see \c remove_copy_if
  */
 template<typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename Predicate>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                          InputIterator first,
                          InputIterator last,
@@ -435,7 +435,7 @@ template<typename InputIterator,
  *  \see \c remove_copy_if
  */
 template<typename DerivedPolicy, typename InputIterator1, typename InputIterator2, typename OutputIterator, typename Predicate>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                          InputIterator1 first,
                          InputIterator1 last,
