@@ -33,7 +33,7 @@
 
 #include <cstddef> // For `std::size_t` and `std::max_align_t`.
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
     #include <type_traits> // For `std::alignment_of`.
 #endif
 
@@ -51,7 +51,7 @@ namespace detail
 /// inside of a `__declspec(align(#))` attribute. As a workaround, you can
 /// assign the result of \p THRUST_ALIGNOF to a variable and pass the variable
 /// as the argument to `__declspec(align(#))`.
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
     #define THRUST_ALIGNOF(x) alignof(x)
 #else
     #define THRUST_ALIGNOF(x) __alignof(x)
@@ -62,7 +62,7 @@ namespace detail
 /// expression.
 ///
 /// It is an implementation of C++11's \p std::alignment_of.
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
     template <typename T>
     using alignment_of = std::alignment_of<T>;
 #else
@@ -105,25 +105,23 @@ namespace detail
 template <std::size_t Align>
 struct aligned_type;
 
-#if THRUST_CPP_DIALECT >= 2011                                                     \
-  && (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                        \
-  && (THRUST_GCC_VERSION >= 40800)
+#if _CCCL_STD_VER >= 2011                                                     \
+  && defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION >= 40800)
     // C++11 implementation, excluding GCC 4.7, which doesn't have `alignas`.
     template <std::size_t Align>
     struct aligned_type
     {
         struct alignas(Align) type {};
     };
-#elif  (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)                    \
-    || (   (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                 \
-        && (THRUST_GCC_VERSION < 40600))
+#elif defined(_CCCL_COMPILER_MSVC) \
+    || (defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION < 40600))
     // C++03 implementation for MSVC and GCC <= 4.5.
     //
     // We have to implement `aligned_type` with specializations for MSVC
     // and GCC 4.2.x and older because they require literals as arguments to
     // their alignment attribute.
 
-    #if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)
+    #if defined(_CCCL_COMPILER_MSVC)
         // MSVC implementation.
         #define THRUST_DEFINE_ALIGNED_TYPE_SPECIALIZATION(X)                  \
             template <>                                                       \
@@ -166,8 +164,8 @@ struct aligned_type;
 /// strict (as large) as that of every scalar type.
 ///
 /// It is an implementation of C++11's \p std::max_align_t.
-#if THRUST_CPP_DIALECT >= 2011                                                     \
-  && (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                        \
+#if _CCCL_STD_VER >= 2011                                                     \
+  && defined(_CCCL_COMPILER_GCC)                                              \
   && (THRUST_GCC_VERSION >= 40900)
     // GCC 4.7 and 4.8 don't have `std::max_align_t`.
     using max_align_t = std::max_align_t;
@@ -195,13 +193,13 @@ struct aligned_type;
 /// \p aligned_reinterpret_cast is responsible for ensuring that the alignment
 /// requirements are actually satisified.
 template <typename T, typename U>
-__host__ __device__
+_CCCL_HOST_DEVICE
 T aligned_reinterpret_cast(U u)
 {
   return reinterpret_cast<T>(reinterpret_cast<void*>(u));
 }
 
-__host__ __device__
+_CCCL_HOST_DEVICE
 inline std::size_t aligned_storage_size(std::size_t n, std::size_t align)
 {
   return ((n + align - 1) / align) * align;
