@@ -32,7 +32,7 @@ namespace detail
 
 
 template<typename Allocator, typename Pointer, typename Size>
-__host__ __device__
+_CCCL_HOST_DEVICE
 inline void default_construct_range(Allocator &a, Pointer p, Size n);
 
 
