@@ -31,7 +31,7 @@ namespace detail
 {
 
 template<typename Allocator, typename Pointer, typename Size>
-__host__ __device__
+_CCCL_HOST_DEVICE
   inline void destroy_range(Allocator &a, Pointer p, Size n);
 
 } // end detail
