@@ -32,7 +32,7 @@ namespace detail
 
 
 template<typename Allocator, typename Pointer, typename Size, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
 inline void fill_construct_range(Allocator &a, Pointer p, Size n, const T &value);
 
 
