@@ -57,128 +57,128 @@ template<typename T, typename Alloc>
     typedef thrust::detail::normal_iterator<pointer>       iterator;
     typedef thrust::detail::normal_iterator<const_pointer> const_iterator;
 
-    __thrust_exec_check_disable__
-    __host__ __device__
+    _CCCL_EXEC_CHECK_DISABLE
+    _CCCL_HOST_DEVICE
     explicit contiguous_storage(const allocator_type &alloc = allocator_type());
 
-    __thrust_exec_check_disable__
-    __host__ __device__
+    _CCCL_EXEC_CHECK_DISABLE
+    _CCCL_HOST_DEVICE
     explicit contiguous_storage(size_type n, const allocator_type &alloc = allocator_type());
 
-    __thrust_exec_check_disable__
-    __host__ __device__
+    _CCCL_EXEC_CHECK_DISABLE
+    _CCCL_HOST_DEVICE
     explicit contiguous_storage(copy_allocator_t, const contiguous_storage &other);
 
-    __thrust_exec_check_disable__
-    __host__ __device__
+    _CCCL_EXEC_CHECK_DISABLE
+    _CCCL_HOST_DEVICE
     explicit contiguous_storage(copy_allocator_t, const contiguous_storage &other, size_type n);
 
-    __thrust_exec_check_disable__
-    __host__ __device__
+    _CCCL_EXEC_CHECK_DISABLE
+    _CCCL_HOST_DEVICE
     ~contiguous_storage();
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     size_type size() const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     size_type max_size() const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     pointer data();
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     const_pointer data() const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator begin();
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     const_iterator begin() const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator end();
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     const_iterator end() const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     reference operator[](size_type n);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     const_reference operator[](size_type n) const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     allocator_type get_allocator() const;
 
     // note that allocate does *not* automatically call deallocate
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void allocate(size_type n);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void deallocate();
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void swap(contiguous_storage &x);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void default_construct_n(iterator first, size_type n);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void uninitialized_fill_n(iterator first, size_type n, const value_type &value);
 
     template<typename InputIterator>
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator uninitialized_copy(InputIterator first, InputIterator last, iterator result);
 
     template<typename System, typename InputIterator>
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator uninitialized_copy(thrust::execution_policy<System> &from_system,
                                 InputIterator first,
                                 InputIterator last,
                                 iterator result);
 
     template<typename InputIterator, typename Size>
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator uninitialized_copy_n(InputIterator first, Size n, iterator result);
 
     template<typename System, typename InputIterator, typename Size>
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     iterator uninitialized_copy_n(thrust::execution_policy<System> &from_system,
                                   InputIterator first,
                                   Size n,
                                   iterator result);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void destroy(iterator first, iterator last);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void deallocate_on_allocator_mismatch(const contiguous_storage &other);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void destroy_on_allocator_mismatch(const contiguous_storage &other,
         iterator first, iterator last);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void set_allocator(const allocator_type &alloc);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     bool is_allocator_not_equal(const allocator_type &alloc) const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     bool is_allocator_not_equal(const contiguous_storage &other) const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void propagate_allocator(const contiguous_storage &other);
 
-#if THRUST_CPP_DIALECT >= 2011
-    __host__ __device__
+#if _CCCL_STD_VER >= 2011
+    _CCCL_HOST_DEVICE
     void propagate_allocator(contiguous_storage &other);
 
     // allow move assignment for a sane implementation of allocator propagation
     // on move assignment
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     contiguous_storage &operator=(contiguous_storage &&other);
-#endif
+#endif // _CCCL_STD_VER >= 2011
 
   private:
     // XXX we could inherit from this to take advantage of empty base class optimization
@@ -191,51 +191,51 @@ template<typename T, typename Alloc>
     // disallow assignment
     contiguous_storage &operator=(const contiguous_storage &x);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void swap_allocators(true_type, const allocator_type &);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void swap_allocators(false_type, allocator_type &);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     bool is_allocator_not_equal_dispatch(true_type, const allocator_type &) const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     bool is_allocator_not_equal_dispatch(false_type, const allocator_type &) const;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void deallocate_on_allocator_mismatch_dispatch(true_type, const contiguous_storage &other);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void deallocate_on_allocator_mismatch_dispatch(false_type, const contiguous_storage &other);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void destroy_on_allocator_mismatch_dispatch(true_type, const contiguous_storage &other,
         iterator first, iterator last);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void destroy_on_allocator_mismatch_dispatch(false_type, const contiguous_storage &other,
         iterator first, iterator last);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void propagate_allocator_dispatch(true_type, const contiguous_storage &other);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void propagate_allocator_dispatch(false_type, const contiguous_storage &other);
 
-#if THRUST_CPP_DIALECT >= 2011
-    __host__ __device__
+#if _CCCL_STD_VER >= 2011
+    _CCCL_HOST_DEVICE
     void propagate_allocator_dispatch(true_type, contiguous_storage &other);
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void propagate_allocator_dispatch(false_type, contiguous_storage &other);
-#endif
+#endif // _CCCL_STD_VER >= 2011
 }; // end contiguous_storage
 
 } // end detail
 
 template<typename T, typename Alloc>
-__host__ __device__
+_CCCL_HOST_DEVICE
 void swap(detail::contiguous_storage<T,Alloc> &lhs, detail::contiguous_storage<T,Alloc> &rhs);
 
 THRUST_NAMESPACE_END
