@@ -27,7 +27,7 @@
 #endif // no system header
 
 #ifndef THRUST_CPP11_REQUIRED_NO_ERROR
-#  if THRUST_CPP_DIALECT < 2011
+#  if _CCCL_STD_VER < 2011
 #    error C++11 is required for this Thrust feature; please upgrade your compiler or pass the appropriate -std=c++XX flag to it.
 #  endif
 #endif
