@@ -38,62 +38,62 @@ struct wrapped_function
   // mutable because Function::operator() might be const
   mutable Function m_f;
 
-  inline __host__ __device__
+  inline _CCCL_HOST_DEVICE
   wrapped_function()
       : m_f()
   {}
 
-  inline __host__ __device__
+  inline _CCCL_HOST_DEVICE
   wrapped_function(const Function& f)
       : m_f(f)
   {}
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(Argument& x) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x)));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(const Argument& x) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x)));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(Argument1& x, Argument2& y) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x),
                                    thrust::raw_reference_cast(y)));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(const Argument1& x, Argument2& y) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x),
                                    thrust::raw_reference_cast(y)));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(const Argument1& x, const Argument2& y) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x),
                                    thrust::raw_reference_cast(y)));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   Result operator()(Argument1& x, const Argument2& y) const
   {
     return static_cast<Result>(m_f(thrust::raw_reference_cast(x),
@@ -107,57 +107,57 @@ struct wrapped_function<Function, void>
 {
   // mutable because Function::operator() might be const
   mutable Function m_f;
-  inline __host__ __device__
+  inline _CCCL_HOST_DEVICE
   wrapped_function()
     : m_f()
   {}
 
-  inline __host__ __device__
+  inline _CCCL_HOST_DEVICE
   wrapped_function(const Function& f)
     : m_f(f)
   {}
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(Argument& x) const
   {
     m_f(thrust::raw_reference_cast(x));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(const Argument& x) const
   {
     m_f(thrust::raw_reference_cast(x));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(Argument1& x, Argument2& y) const
   {
     m_f(thrust::raw_reference_cast(x), thrust::raw_reference_cast(y));
   }
 
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(const Argument1& x, Argument2& y) const
   {
     m_f(thrust::raw_reference_cast(x), thrust::raw_reference_cast(y));
   }
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(const Argument1& x, const Argument2& y) const
   {
     m_f(thrust::raw_reference_cast(x), thrust::raw_reference_cast(y));
   }
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename Argument1, typename Argument2>
-  __thrust_forceinline__ __host__ __device__
+  _CCCL_FORCEINLINE _CCCL_HOST_DEVICE
   void operator()(Argument1& x, const Argument2& y) const
   {
     m_f(thrust::raw_reference_cast(x), thrust::raw_reference_cast(y));
