@@ -48,9 +48,9 @@ struct depend_on_instantiation
   THRUST_INLINE_INTEGRAL_MEMBER_CONSTANT bool value = x;
 };
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 
-#  if THRUST_CPP_DIALECT >= 2017
+#  if _CCCL_STD_VER >= 2017
 #    define THRUST_STATIC_ASSERT(B)        static_assert(B)
 #  else
 #    define THRUST_STATIC_ASSERT(B)        static_assert(B, "static assertion failed")
@@ -67,9 +67,8 @@ template <> struct STATIC_ASSERTION_FAILURE<true> {};
 // HP aCC cannot deal with missing names for template value parameters.
 template <int x> struct static_assert_test {};
 
-#if    (  (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                  \
-       && (THRUST_GCC_VERSION >= 40800))                                      \
-    || (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_CLANG)
+#  if (defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION >= 40800))          \
+      || defined(_CCCL_COMPILER_CLANG)
   // Clang and GCC 4.8+ will complain about this typedef being unused unless we
   // annotate it as such.
 #  define THRUST_STATIC_ASSERT(B)                                             \
@@ -90,10 +89,8 @@ template <int x> struct static_assert_test {};
 
 #define THRUST_STATIC_ASSERT_MSG(B, msg) THRUST_STATIC_ASSERT(B)
 
-#endif // THRUST_CPP_DIALECT >= 2011
+#endif // _CCCL_STD_VER >= 2011
 
 } // namespace detail
 
 THRUST_NAMESPACE_END
-
-
