@@ -29,9 +29,9 @@
 
 THRUST_NAMESPACE_BEGIN
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template<typename Assignable1, typename Assignable2>
-__host__ __device__
+_CCCL_HOST_DEVICE
 inline void swap(Assignable1 &a, Assignable2 &b)
 {
   Assignable1 temp = a;
