@@ -34,8 +34,6 @@
 
 #include <cuda/std/type_traits>
 
-#include <type_traits>
-
 THRUST_NAMESPACE_BEGIN
 
 // forward declaration of device_reference
@@ -105,11 +103,10 @@ template<typename T> struct is_pod
    : public integral_constant<
        bool,
        is_void<T>::value || is_pointer<T>::value || is_arithmetic<T>::value
-#if THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC || \
-    THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_CLANG
+#if defined(_CCCL_COMPILER_MSVC) || defined(_CCCL_COMPILER_CLANG)
 // use intrinsic type traits
        || __is_pod(T)
-#elif THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC
+#elif defined(_CCCL_COMPILER_GCC)
 // only use the intrinsic for >= 4.3
 #if (__GNUC__ * 100 + __GNUC_MINOR__ >= 403)
        || __is_pod(T)
@@ -256,7 +253,7 @@ template<typename T1, typename T2>
 {
 }; // end lazy_is_different
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 
 template<class From, class To>
 using is_convertible = ::cuda::std::is_convertible<From, To>;
@@ -443,6 +440,8 @@ template<typename T1, typename T2, typename T = void>
     : enable_if< is_convertible<T1,T2>::value, T >
 {};
 
+template<typename T1, typename T2, typename T = void>
+using enable_if_convertible_t = typename enable_if_convertible<T1, T2, T>::type;
 
 template<typename T1, typename T2, typename T = void>
   struct disable_if_convertible
@@ -455,7 +454,6 @@ template<typename T1, typename T2, typename Result = void>
     : enable_if<is_different<T1,T2>::value, Result>
 {};
 
-
 template<typename T>
   struct is_numeric
     : and_<
@@ -541,7 +539,7 @@ template<typename T1, typename T2>
       >
 {};
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 
 template<class Base, class Derived>
 using is_base_of = ::cuda::std::is_base_of<Base, Derived>;
@@ -638,7 +636,7 @@ template<typename T1, typename T2, typename Enable = void> struct promoted_numer
 
 template<typename T1, typename T2>
   struct promoted_numerical_type<T1,T2,typename enable_if<and_
-  <typename is_floating_point<T1>::type, typename is_floating_point<T2>::type>
+  <typename is_floating_point<T1>::type,typename is_floating_point<T2>::type>
   ::value>::type>
   {
   typedef typename larger_type<T1,T2>::type type;
@@ -646,7 +644,7 @@ template<typename T1, typename T2>
 
 template<typename T1, typename T2>
   struct promoted_numerical_type<T1,T2,typename enable_if<and_
-  <typename is_integral<T1>::type, typename is_floating_point<T2>::type>
+  <typename is_integral<T1>::type,typename is_floating_point<T2>::type>
   ::value>::type>
   {
   typedef T2 type;
@@ -678,7 +676,7 @@ template<typename T>
 
 template <typename Invokable, typename... Args>
 using invoke_result_t =
-#if THRUST_CPP_DIALECT < 2017
+#if _CCCL_STD_VER < 2017
   typename ::cuda::std::result_of<Invokable(Args...)>::type;
 #else // 2017+
   ::cuda::std::invoke_result_t<Invokable, Args...>;
