@@ -151,9 +151,9 @@ struct binary_function
   struct func<void>                                                            \
   {                                                                            \
     using is_transparent = void;                                               \
-    __thrust_exec_check_disable__                                              \
+    _CCCL_EXEC_CHECK_DISABLE                                              \
     template <typename T>                                                      \
-    __host__ __device__                                                        \
+    _CCCL_HOST_DEVICE                                                        \
     constexpr auto operator()(T&& x) const                                     \
       noexcept(noexcept(impl)) THRUST_TRAILING_RETURN(decltype(impl))          \
     {                                                                          \
@@ -166,9 +166,9 @@ struct binary_function
   struct func<void>                                                            \
   {                                                                            \
     using is_transparent = void;                                               \
-    __thrust_exec_check_disable__                                              \
+    _CCCL_EXEC_CHECK_DISABLE                                              \
     template <typename T1, typename T2>                                        \
-    __host__ __device__                                                        \
+    _CCCL_HOST_DEVICE                                                        \
     constexpr auto operator()(T1&& t1, T2&& t2) const                          \
       noexcept(noexcept(impl)) THRUST_TRAILING_RETURN(decltype(impl))          \
     {                                                                          \
@@ -234,8 +234,8 @@ struct plus
 
   /*! Function call operator. The return value is <tt>lhs + rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs + rhs;
@@ -297,8 +297,8 @@ struct minus
 
   /*! Function call operator. The return value is <tt>lhs - rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs - rhs;
@@ -360,8 +360,8 @@ struct multiplies
 
   /*! Function call operator. The return value is <tt>lhs * rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs * rhs;
@@ -423,8 +423,8 @@ struct divides
 
   /*! Function call operator. The return value is <tt>lhs / rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs / rhs;
@@ -486,8 +486,8 @@ struct modulus
 
   /*! Function call operator. The return value is <tt>lhs % rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs % rhs;
@@ -541,8 +541,8 @@ struct negate
 
   /*! Function call operator. The return value is <tt>-x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &x) const
   {
     return -x;
@@ -595,8 +595,8 @@ struct square
 
   /*! Function call operator. The return value is <tt>x*x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &x) const
   {
     return x*x;
@@ -644,8 +644,8 @@ struct equal_to
 
   /*! Function call operator. The return value is <tt>lhs == rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs == rhs;
@@ -685,8 +685,8 @@ struct not_equal_to
 
   /*! Function call operator. The return value is <tt>lhs != rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs != rhs;
@@ -726,8 +726,8 @@ struct greater
 
   /*! Function call operator. The return value is <tt>lhs > rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs > rhs;
@@ -767,8 +767,8 @@ struct less
 
   /*! Function call operator. The return value is <tt>lhs < rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs;
@@ -808,8 +808,8 @@ struct greater_equal
 
   /*! Function call operator. The return value is <tt>lhs >= rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs >= rhs;
@@ -849,8 +849,8 @@ struct less_equal
 
   /*! Function call operator. The return value is <tt>lhs <= rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs <= rhs;
@@ -899,8 +899,8 @@ struct logical_and
 
   /*! Function call operator. The return value is <tt>lhs && rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs && rhs;
@@ -940,8 +940,8 @@ struct logical_or
 
   /*! Function call operator. The return value is <tt>lhs || rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &lhs, const T &rhs) const
   {
     return lhs || rhs;
@@ -995,8 +995,8 @@ struct logical_not
 
   /*! Function call operator. The return value is <tt>!x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr bool operator()(const T &x) const
   {
     return !x;
@@ -1065,8 +1065,8 @@ struct bit_and
 
   /*! Function call operator. The return value is <tt>lhs & rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs & rhs;
@@ -1127,8 +1127,8 @@ struct bit_or
 
   /*! Function call operator. The return value is <tt>lhs | rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs | rhs;
@@ -1189,8 +1189,8 @@ struct bit_xor
 
   /*! Function call operator. The return value is <tt>lhs ^ rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs ^ rhs;
@@ -1242,8 +1242,8 @@ struct identity
 
   /*! Function call operator. The return value is <tt>x</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr const T &operator()(const T &x) const
   {
     return x;
@@ -1296,8 +1296,8 @@ struct maximum
 
   /*! Function call operator. The return value is <tt>rhs < lhs ? lhs : rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs ? rhs : lhs;
@@ -1352,8 +1352,8 @@ struct minimum
 
   /*! Function call operator. The return value is <tt>lhs < rhs ? lhs : rhs</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   constexpr T operator()(const T &lhs, const T &rhs) const
   {
     return lhs < rhs ? lhs : rhs;
@@ -1402,7 +1402,7 @@ struct project1st
 
   /*! Function call operator. The return value is <tt>lhs</tt>.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr const T1 &operator()(const T1 &lhs, const T2 & /*rhs*/) const
   {
     return lhs;
@@ -1413,9 +1413,9 @@ template <>
 struct project1st<void, void>
 {
   using is_transparent = void;
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename T1, typename T2>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr auto operator()(T1&& t1, T2&&) const
     noexcept(noexcept(THRUST_FWD(t1)))
     THRUST_TRAILING_RETURN(decltype(THRUST_FWD(t1)))
@@ -1462,7 +1462,7 @@ struct project2nd
 
   /*! Function call operator. The return value is <tt>rhs</tt>.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr const T2 &operator()(const T1 &/*lhs*/, const T2 &rhs) const
   {
     return rhs;
@@ -1473,9 +1473,9 @@ template <>
 struct project2nd<void, void>
 {
   using is_transparent = void;
-  __thrust_exec_check_disable__
+  _CCCL_EXEC_CHECK_DISABLE
   template <typename T1, typename T2>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr auto operator()(T1&&, T2&& t2) const
   noexcept(noexcept(THRUST_FWD(t2)))
   THRUST_TRAILING_RETURN(decltype(THRUST_FWD(t2)))
@@ -1511,13 +1511,13 @@ struct unary_negate
   /*! Constructor takes a \p Predicate object to negate.
    *  \param p The \p Predicate object to negate.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   explicit unary_negate(Predicate p) : pred(p){}
 
   /*! Function call operator. The return value is <tt>!pred(x)</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   bool operator()(const typename Predicate::argument_type& x) { return !pred(x); }
 
   /*! \cond
@@ -1544,7 +1544,7 @@ struct unary_negate
  *  \see not2
  */
 template<typename Predicate>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   unary_negate<Predicate> not1(const Predicate &pred);
 
 /*! \p binary_negate is a function object adaptor: it is an Adaptable Binary
@@ -1566,13 +1566,13 @@ struct binary_negate
   /*! Constructor takes a \p Predicate object to negate.
    *  \param p The \p Predicate object to negate.
    */
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   explicit binary_negate(Predicate p) : pred(p){}
 
   /*! Function call operator. The return value is <tt>!pred(x,y)</tt>.
    */
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   bool operator()(const typename Predicate::first_argument_type& x, const typename Predicate::second_argument_type& y)
   {
       return !pred(x,y);
@@ -1602,7 +1602,7 @@ struct binary_negate
  *  \see not1
  */
 template<typename BinaryPredicate>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   binary_negate<BinaryPredicate> not2(const BinaryPredicate &pred);
 
 /*! \}
