@@ -31,7 +31,7 @@
 #endif // no system header
 #include <thrust/detail/cpp14_required.h>
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 
 #include <thrust/execution_policy.h>
 #include <thrust/detail/static_assert.h>
@@ -78,14 +78,14 @@ namespace unimplemented
 
 struct no_unique_eager_event_type_found {};
 
-inline __host__
+inline _CCCL_HOST
 no_unique_eager_event_type_found
 unique_eager_event_type(...) noexcept;
 
 struct no_unique_eager_future_type_found {};
 
 template <typename T>
-__host__
+_CCCL_HOST
 no_unique_eager_future_type_found
 unique_eager_future_type(...) noexcept;
 
