@@ -74,14 +74,14 @@ template<typename T, typename Alloc = std::allocator<T> >
 
     /*! This constructor creates an empty \p host_vector.
      */
-    __host__
+    _CCCL_HOST
     host_vector(void)
       :Parent() {}
 
     /*! This constructor creates an empty \p host_vector.
      *  \param alloc The allocator to use by this host_vector.
      */
-    __host__
+    _CCCL_HOST
     host_vector(const Alloc &alloc)
       :Parent(alloc) {}
 
@@ -89,14 +89,14 @@ template<typename T, typename Alloc = std::allocator<T> >
      */
     //  Define an empty destructor to explicitly specify
     //  its execution space qualifier, as a workaround for nvcc warning
-    __host__
+    _CCCL_HOST
     ~host_vector(void) {}
 
     /*! This constructor creates a \p host_vector with the given
      *  size.
      *  \param n The number of elements to initially create.
      */
-    __host__
+    _CCCL_HOST
     explicit host_vector(size_type n)
       :Parent(n) {}
 
@@ -105,7 +105,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param n The number of elements to initially create.
      *  \param alloc The allocator to use by this host_vector.
      */
-    __host__
+    _CCCL_HOST
     explicit host_vector(size_type n, const Alloc &alloc)
       :Parent(n,alloc) {}
 
@@ -114,7 +114,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param n The number of elements to initially create.
      *  \param value An element to copy.
      */
-    __host__
+    _CCCL_HOST
     explicit host_vector(size_type n, const value_type &value)
       :Parent(n,value) {}
 
@@ -124,14 +124,14 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param value An element to copy.
      *  \param alloc The allocator to use by this host_vector.
      */
-    __host__
+    _CCCL_HOST
     explicit host_vector(size_type n, const value_type &value, const Alloc &alloc)
       :Parent(n,value,alloc) {}
 
     /*! Copy constructor copies from an exemplar \p host_vector.
      *  \param v The \p host_vector to copy.
      */
-    __host__
+    _CCCL_HOST
     host_vector(const host_vector &v)
       :Parent(v) {}
 
@@ -139,15 +139,15 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The \p host_vector to copy.
      *  \param alloc The allocator to use by this host_vector.
      */
-    __host__
+    _CCCL_HOST
     host_vector(const host_vector &v, const Alloc &alloc)
       :Parent(v,alloc) {}
 
-  #if THRUST_CPP_DIALECT >= 2011
+  #if _CCCL_STD_VER >= 2011
     /*! Move constructor moves from another host_vector.
      *  \param v The host_vector to move.
      */
-     __host__
+     _CCCL_HOST
     host_vector(host_vector &&v)
       :Parent(std::move(v)) {}
 
@@ -155,7 +155,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The host_vector to move.
      *  \param alloc The allocator to use by this host_vector.
      */
-     __host__
+     _CCCL_HOST
     host_vector(host_vector &&v, const Alloc &alloc)
       :Parent(std::move(v),alloc) {}
   #endif
@@ -163,15 +163,15 @@ template<typename T, typename Alloc = std::allocator<T> >
   /*! Assign operator copies from an exemplar \p host_vector.
    *  \param v The \p host_vector to copy.
    */
-  __host__
+  _CCCL_HOST
   host_vector &operator=(const host_vector &v)
   { Parent::operator=(v); return *this; }
 
-  #if THRUST_CPP_DIALECT >= 2011
+  #if _CCCL_STD_VER >= 2011
     /*! Move assign operator moves from another host_vector.
      *  \param v The host_vector to move.
      */
-     __host__
+     _CCCL_HOST
      host_vector &operator=(host_vector &&v)
      { Parent::operator=(std::move(v)); return *this; }
   #endif
@@ -180,7 +180,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The \p host_vector to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector(const host_vector<OtherT,OtherAlloc> &v)
       :Parent(v) {}
 
@@ -188,7 +188,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The \p host_vector to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector &operator=(const host_vector<OtherT,OtherAlloc> &v)
     { Parent::operator=(v); return *this; }
 
@@ -196,7 +196,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The <tt>std::vector</tt> to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector(const std::vector<OtherT,OtherAlloc> &v)
       :Parent(v) {}
 
@@ -204,7 +204,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The <tt>std::vector</tt> to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector &operator=(const std::vector<OtherT,OtherAlloc> &v)
     { Parent::operator=(v); return *this;}
 
@@ -214,7 +214,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The \p vector_base to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector(const detail::vector_base<OtherT,OtherAlloc> &v)
       :Parent(v) {}
 
@@ -223,7 +223,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param v The \p vector_base to copy.
      */
     template<typename OtherT, typename OtherAlloc>
-    __host__
+    _CCCL_HOST
     host_vector &operator=(const detail::vector_base<OtherT,OtherAlloc> &v)
     { Parent::operator=(v); return *this; }
 
@@ -251,7 +251,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param last The end of the range.
      */
     template<typename InputIterator>
-    __host__
+    _CCCL_HOST
     host_vector(InputIterator first, InputIterator last)
       :Parent(first, last) {}
 
@@ -261,7 +261,7 @@ template<typename T, typename Alloc = std::allocator<T> >
      *  \param alloc The allocator to use by this host_vector.
      */
     template<typename InputIterator>
-    __host__
+    _CCCL_HOST
     host_vector(InputIterator first, InputIterator last, const Alloc &alloc)
       :Parent(first, last, alloc) {}
 
