@@ -121,7 +121,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
      *
      *  \param value The seed used to intialize this \p subtract_with_carry_engine's state.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     explicit subtract_with_carry_engine(result_type value = default_seed);
 
     /*! This method initializes this \p subtract_with_carry_engine's state, and optionally accepts
@@ -129,7 +129,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
      *
      *  \param value The seed used to initializes this \p subtract_with_carry_engine's state.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void seed(result_type value = default_seed);
 
     // generating functions
@@ -137,7 +137,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
     /*! This member function produces a new random value and updates this \p subtract_with_carry_engine's state.
      *  \return A new random number.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     result_type operator()(void);
 
     /*! This member function advances this \p subtract_with_carry_engine's state a given number of times
@@ -146,7 +146,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
      *  \param z The number of random values to discard.
      *  \note This function is provided because an implementation may be able to accelerate it.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void discard(unsigned long long z);
 
     /*! \cond
@@ -158,7 +158,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
 
     friend struct thrust::random::detail::random_core_access;
 
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     bool equal(const subtract_with_carry_engine &rhs) const;
 
     template<typename CharT, typename Traits>
@@ -178,7 +178,7 @@ template<typename UIntType, size_t w, size_t s, size_t r>
  *  \return \c true if \p lhs is equal to \p rhs; \c false, otherwise.
  */
 template<typename UIntType_, size_t w_, size_t s_, size_t r_>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator==(const subtract_with_carry_engine<UIntType_,w_,s_,r_> &lhs,
                 const subtract_with_carry_engine<UIntType_,w_,s_,r_> &rhs);
 
@@ -189,7 +189,7 @@ bool operator==(const subtract_with_carry_engine<UIntType_,w_,s_,r_> &lhs,
  *  \return \c true if \p lhs is not equal to \p rhs; \c false, otherwise.
  */
 template<typename UIntType_, size_t w_, size_t s_, size_t r_>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool operator!=(const subtract_with_carry_engine<UIntType_,w_,s_,r_>&lhs,
                 const subtract_with_carry_engine<UIntType_,w_,s_,r_>&rhs);
 
