@@ -90,7 +90,7 @@ THRUST_NAMESPACE_BEGIN
  *  \see \c replace_copy_if
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void replace(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                ForwardIterator first, ForwardIterator last,
                const T &old_value,
@@ -204,7 +204,7 @@ template<typename ForwardIterator, typename T>
  *  \see \c replace_copy_if
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename Predicate, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void replace_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                   ForwardIterator first, ForwardIterator last,
                   Predicate pred,
@@ -338,7 +338,7 @@ template<typename ForwardIterator, typename Predicate, typename T>
  *  \see \c replace_copy_if
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename InputIterator, typename Predicate, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void replace_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                   ForwardIterator first, ForwardIterator last,
                   InputIterator stencil,
@@ -467,7 +467,7 @@ template<typename ForwardIterator, typename InputIterator, typename Predicate, t
  *  \see \c replace_copy_if
  */
 template<typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator replace_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                               InputIterator first, InputIterator last,
                               OutputIterator result,
@@ -592,7 +592,7 @@ template<typename InputIterator, typename OutputIterator, typename T>
  *  \see \c replace_copy
  */
 template<typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename Predicate, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator replace_copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                  InputIterator first, InputIterator last,
                                  OutputIterator result,
@@ -736,7 +736,7 @@ template<typename InputIterator, typename OutputIterator, typename Predicate, ty
  *  \see \c replace_if
  */
 template<typename DerivedPolicy, typename InputIterator1, typename InputIterator2, typename OutputIterator, typename Predicate, typename T>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator replace_copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                  InputIterator1 first, InputIterator1 last,
                                  InputIterator2 stencil,
