@@ -81,7 +81,7 @@ THRUST_NAMESPACE_BEGIN
  *  \see \p sort_by_key
  */
 template<typename DerivedPolicy, typename RandomAccessIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void sort(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
             RandomAccessIterator first,
             RandomAccessIterator last);
@@ -173,7 +173,7 @@ template<typename RandomAccessIterator>
 template<typename DerivedPolicy,
          typename RandomAccessIterator,
          typename StrictWeakOrdering>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void sort(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
             RandomAccessIterator first,
             RandomAccessIterator last,
@@ -220,7 +220,7 @@ __host__ __device__
  */
 template<typename RandomAccessIterator,
          typename StrictWeakOrdering>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void sort(RandomAccessIterator first,
             RandomAccessIterator last,
             StrictWeakOrdering comp);
@@ -271,7 +271,7 @@ __host__ __device__
  *  \see \p stable_sort_by_key
  */
 template<typename DerivedPolicy, typename RandomAccessIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void stable_sort(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    RandomAccessIterator first,
                    RandomAccessIterator last);
@@ -371,7 +371,7 @@ template<typename RandomAccessIterator>
 template<typename DerivedPolicy,
          typename RandomAccessIterator,
          typename StrictWeakOrdering>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void stable_sort(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    RandomAccessIterator first,
                    RandomAccessIterator last,
@@ -489,7 +489,7 @@ template<typename RandomAccessIterator,
 template<typename DerivedPolicy,
          typename RandomAccessIterator1,
          typename RandomAccessIterator2>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void sort_by_key(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    RandomAccessIterator1 keys_first,
                    RandomAccessIterator1 keys_last,
@@ -611,7 +611,7 @@ template<typename DerivedPolicy,
          typename RandomAccessIterator1,
          typename RandomAccessIterator2,
          typename StrictWeakOrdering>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void sort_by_key(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                    RandomAccessIterator1 keys_first,
                    RandomAccessIterator1 keys_last,
@@ -738,7 +738,7 @@ template<typename RandomAccessIterator1,
 template<typename DerivedPolicy,
          typename RandomAccessIterator1,
          typename RandomAccessIterator2>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void stable_sort_by_key(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                           RandomAccessIterator1 keys_first,
                           RandomAccessIterator1 keys_last,
@@ -865,7 +865,7 @@ template<typename DerivedPolicy,
          typename RandomAccessIterator1,
          typename RandomAccessIterator2,
          typename StrictWeakOrdering>
-__host__ __device__
+_CCCL_HOST_DEVICE
   void stable_sort_by_key(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                           RandomAccessIterator1 keys_first,
                           RandomAccessIterator1 keys_last,
@@ -1003,7 +1003,7 @@ template<typename RandomAccessIterator1,
  *  \see \c less<T>
  */
 template<typename DerivedPolicy, typename ForwardIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   bool is_sorted(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                  ForwardIterator first,
                  ForwardIterator last);
@@ -1118,7 +1118,7 @@ template<typename ForwardIterator>
  *  \see \c less<T>
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename Compare>
-__host__ __device__
+_CCCL_HOST_DEVICE
   bool is_sorted(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                  ForwardIterator first,
                  ForwardIterator last,
@@ -1219,7 +1219,7 @@ template<typename ForwardIterator, typename Compare>
  *  \see \p stable_sort_by_key
  */
 template<typename DerivedPolicy, typename ForwardIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   ForwardIterator is_sorted_until(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                   ForwardIterator first,
                                   ForwardIterator last);
@@ -1307,7 +1307,7 @@ template<typename ForwardIterator>
  *  \see \p stable_sort_by_key
  */
 template<typename DerivedPolicy, typename ForwardIterator, typename Compare>
-__host__ __device__
+_CCCL_HOST_DEVICE
   ForwardIterator is_sorted_until(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
                                   ForwardIterator first,
                                   ForwardIterator last,
