@@ -40,7 +40,7 @@
 #endif // no system header
 #include <thrust/detail/cpp14_required.h>
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
 
@@ -53,6 +53,8 @@
 #include <thrust/distance.h>
 #include <thrust/advance.h>
 
+#include <cub/device/device_for.cuh>
+
 #include <type_traits>
 
 THRUST_NAMESPACE_BEGIN
@@ -67,13 +69,13 @@ struct async_transform_fn
   OutputIt output_;
   UnaryOperation op_;
 
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   async_transform_fn(ForwardIt&& first, OutputIt&& output, UnaryOperation&& op)
     : first_(std::move(first)), output_(std::move(output)), op_(std::move(op))
   {}
 
   template <typename Index>
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   void operator()(Index idx)
   {
     output_[idx] = op_(thrust::raw_reference_cast(first_[idx]));
@@ -126,7 +128,7 @@ unique_eager_event async_transform_n(
   );
 
   thrust::cuda_cub::throw_on_error(
-    thrust::cuda_cub::__parallel_for::parallel_for(
+    cub::DeviceFor::Bulk(
       n, std::move(wrapped), e.stream().native_handle()
     )
   , "after transform launch"
