@@ -35,13 +35,12 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/system/cuda/detail/guarded_cuda_runtime_api.h>
 #include <thrust/system/cuda/detail/execution_policy.h>
 #include <thrust/system/cuda/detail/util.h>
 
 #include <thrust/detail/allocator_aware_execution_policy.h>
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 #  include <thrust/detail/dependencies_aware_execution_policy.h>
 #endif
 
@@ -56,8 +55,8 @@ private:
   cudaStream_t stream;
 
 public:
-  __thrust_exec_check_disable__
-  __host__ __device__
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE
   execute_on_stream_base(cudaStream_t stream_ = default_stream())
       : stream(stream_){}
 
@@ -71,7 +70,7 @@ public:
   }
 
 private:
-  friend __host__ __device__
+  friend _CCCL_HOST_DEVICE
   cudaStream_t
   get_stream(const execute_on_stream_base &exec)
   {
@@ -86,7 +85,7 @@ private:
   cudaStream_t stream;
 
 public:
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   execute_on_stream_nosync_base(cudaStream_t stream_ = default_stream())
       : stream(stream_){}
 
@@ -100,14 +99,14 @@ public:
   }
 
 private:
-  friend __host__ __device__
+  friend _CCCL_HOST_DEVICE
   cudaStream_t
   get_stream(const execute_on_stream_nosync_base &exec)
   {
     return exec.stream;
   }
 
-  friend __host__ __device__
+  friend _CCCL_HOST_DEVICE
   bool
   must_perform_optional_stream_synchronization(const execute_on_stream_nosync_base &)
   {
@@ -119,9 +118,9 @@ struct execute_on_stream : execute_on_stream_base<execute_on_stream>
 {
   typedef execute_on_stream_base<execute_on_stream> base_t;
 
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   execute_on_stream() : base_t(){};
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   execute_on_stream(cudaStream_t stream)
   : base_t(stream){};
 };
@@ -130,9 +129,9 @@ struct execute_on_stream_nosync : execute_on_stream_nosync_base<execute_on_strea
 {
   typedef execute_on_stream_nosync_base<execute_on_stream_nosync> base_t;
 
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   execute_on_stream_nosync() : base_t(){};
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   execute_on_stream_nosync(cudaStream_t stream)
   : base_t(stream){};
 };
@@ -141,14 +140,14 @@ struct execute_on_stream_nosync : execute_on_stream_nosync_base<execute_on_strea
 struct par_t : execution_policy<par_t>,
   thrust::detail::allocator_aware_execution_policy<
     execute_on_stream_base>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 , thrust::detail::dependencies_aware_execution_policy<
     execute_on_stream_base>
 #endif
 {
   typedef execution_policy<par_t> base_t;
 
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr par_t() : base_t() {}
 
   typedef execute_on_stream stream_attachment_type;
@@ -164,14 +163,14 @@ struct par_t : execution_policy<par_t>,
 struct par_nosync_t : execution_policy<par_nosync_t>,
   thrust::detail::allocator_aware_execution_policy<
     execute_on_stream_nosync_base>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 , thrust::detail::dependencies_aware_execution_policy<
     execute_on_stream_nosync_base>
 #endif
 {
   typedef execution_policy<par_nosync_t> base_t;
 
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   constexpr par_nosync_t() : base_t() {}
 
   typedef execute_on_stream_nosync stream_attachment_type;
@@ -186,7 +185,7 @@ struct par_nosync_t : execution_policy<par_nosync_t>,
 private:
   //this function is defined to allow non-blocking calls on the default_stream() with thrust::cuda::par_nosync
   //without explicitly using thrust::cuda::par_nosync.on(default_stream())
-  friend __host__ __device__
+  friend _CCCL_HOST_DEVICE
   bool
   must_perform_optional_stream_synchronization(const par_nosync_t &)
   {
