@@ -67,7 +67,7 @@ template <typename DerivedPolicy,
           typename OutputIterator1,
           typename OutputIterator2,
           typename BinaryPredicate>
-__host__ __device__ thrust::pair<OutputIterator1, OutputIterator2>
+_CCCL_HOST_DEVICE thrust::pair<OutputIterator1, OutputIterator2>
 reduce_by_key(
     const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
     InputIterator1                                              keys_first,
@@ -688,7 +688,7 @@ namespace __reduce_by_key {
         }
 
         key_type tile_pred_key = (threadIdx.x == 0)
-                                     ? keys_load_it[tile_offset - 1]
+                                     ? key_type(keys_load_it[tile_offset - 1])
                                      : key_type();
 
         sync_threadblock();
@@ -1057,7 +1057,7 @@ namespace __reduce_by_key {
     status = cuda_cub::synchronize(policy);
     cuda_cub::throw_on_error(status, "reduce_by_key: failed to synchronize");
 
-    int num_runs_out = cuda_cub::get_value(policy, d_num_runs_out);
+    const auto num_runs_out = cuda_cub::get_value(policy, d_num_runs_out);
 
     return thrust::make_pair(
       keys_output + num_runs_out,
@@ -1115,7 +1115,7 @@ namespace __reduce_by_key {
 // Thrust API entry points
 //-------------------------
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class KeyInputIt,
           class ValInputIt,
@@ -1123,7 +1123,7 @@ template <class Derived,
           class ValOutputIt,
           class BinaryPred,
           class BinaryOp>
-pair<KeyOutputIt, ValOutputIt> __host__ __device__
+pair<KeyOutputIt, ValOutputIt> _CCCL_HOST_DEVICE
 reduce_by_key(execution_policy<Derived> &policy,
               KeyInputIt                 keys_first,
               KeyInputIt                 keys_last,
@@ -1160,7 +1160,7 @@ template <class Derived,
           class KeyOutputIt,
           class ValOutputIt,
           class BinaryPred>
-pair<KeyOutputIt, ValOutputIt> __host__ __device__
+pair<KeyOutputIt, ValOutputIt> _CCCL_HOST_DEVICE
 reduce_by_key(execution_policy<Derived> &policy,
               KeyInputIt                 keys_first,
               KeyInputIt                 keys_last,
@@ -1189,7 +1189,7 @@ template <class Derived,
           class ValInputIt,
           class KeyOutputIt,
           class ValOutputIt>
-pair<KeyOutputIt, ValOutputIt> __host__ __device__
+pair<KeyOutputIt, ValOutputIt> _CCCL_HOST_DEVICE
 reduce_by_key(execution_policy<Derived> &policy,
               KeyInputIt                 keys_first,
               KeyInputIt                 keys_last,
