@@ -1354,13 +1354,13 @@ namespace __set_operations {
 // Thrust API entry points
 //-------------------------
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt,
           class CompareOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_difference(execution_policy<Derived> &policy,
                ItemsIt1                   items1_first,
                ItemsIt1                   items1_last,
@@ -1399,7 +1399,7 @@ template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_difference(execution_policy<Derived> &policy,
                ItemsIt1                   items1_first,
                ItemsIt1                   items1_last,
@@ -1420,13 +1420,13 @@ set_difference(execution_policy<Derived> &policy,
 /*****************************/
 
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt,
           class CompareOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_intersection(execution_policy<Derived> &policy,
                  ItemsIt1                   items1_first,
                  ItemsIt1                   items1_last,
@@ -1465,7 +1465,7 @@ template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_intersection(execution_policy<Derived> &policy,
                  ItemsIt1                   items1_first,
                  ItemsIt1                   items1_last,
@@ -1486,13 +1486,13 @@ set_intersection(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt,
           class CompareOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_symmetric_difference(execution_policy<Derived> &policy,
                          ItemsIt1                   items1_first,
                          ItemsIt1                   items1_last,
@@ -1531,7 +1531,7 @@ template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_symmetric_difference(execution_policy<Derived> &policy,
                          ItemsIt1                   items1_first,
                          ItemsIt1                   items1_last,
@@ -1551,13 +1551,13 @@ set_symmetric_difference(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt,
           class CompareOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_union(execution_policy<Derived> &policy,
           ItemsIt1                   items1_first,
           ItemsIt1                   items1_last,
@@ -1596,7 +1596,7 @@ template <class Derived,
           class ItemsIt1,
           class ItemsIt2,
           class OutputIt>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 set_union(execution_policy<Derived> &policy,
           ItemsIt1                   items1_first,
           ItemsIt1                   items1_last,
@@ -1623,7 +1623,7 @@ set_union(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class KeysIt1,
           class KeysIt2,
@@ -1632,7 +1632,7 @@ template <class Derived,
           class KeysOutputIt,
           class ItemsOutputIt,
           class CompareOp>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_difference_by_key(execution_policy<Derived> &policy,
                       KeysIt1                    keys1_first,
                       KeysIt1                    keys1_last,
@@ -1678,7 +1678,7 @@ template <class Derived,
           class ItemsIt2,
           class KeysOutputIt,
           class ItemsOutputIt>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_difference_by_key(execution_policy<Derived> &policy,
                       KeysIt1                    keys1_first,
                       KeysIt1                    keys1_last,
@@ -1704,7 +1704,7 @@ set_difference_by_key(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class KeysIt1,
           class KeysIt2,
@@ -1713,7 +1713,7 @@ template <class Derived,
           class KeysOutputIt,
           class ItemsOutputIt,
           class CompareOp>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_intersection_by_key(execution_policy<Derived> &policy,
                         KeysIt1                    keys1_first,
                         KeysIt1                    keys1_last,
@@ -1757,7 +1757,7 @@ template <class Derived,
           class ItemsIt2,
           class KeysOutputIt,
           class ItemsOutputIt>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_intersection_by_key(execution_policy<Derived> &policy,
                         KeysIt1                    keys1_first,
                         KeysIt1                    keys1_last,
@@ -1781,7 +1781,7 @@ set_intersection_by_key(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class KeysIt1,
           class KeysIt2,
@@ -1790,7 +1790,7 @@ template <class Derived,
           class KeysOutputIt,
           class ItemsOutputIt,
           class CompareOp>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_symmetric_difference_by_key(execution_policy<Derived> &policy,
                                 KeysIt1                    keys1_first,
                                 KeysIt1                    keys1_last,
@@ -1837,7 +1837,7 @@ template <class Derived,
           class ItemsIt2,
           class KeysOutputIt,
           class ItemsOutputIt>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_symmetric_difference_by_key(execution_policy<Derived> &policy,
                                 KeysIt1                    keys1_first,
                                 KeysIt1                    keys1_last,
@@ -1863,7 +1863,7 @@ set_symmetric_difference_by_key(execution_policy<Derived> &policy,
 
 /*****************************/
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived,
           class KeysIt1,
           class KeysIt2,
@@ -1872,7 +1872,7 @@ template <class Derived,
           class KeysOutputIt,
           class ItemsOutputIt,
           class CompareOp>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_union_by_key(execution_policy<Derived> &policy,
                  KeysIt1                    keys1_first,
                  KeysIt1                    keys1_last,
@@ -1918,7 +1918,7 @@ template <class Derived,
           class ItemsIt2,
           class KeysOutputIt,
           class ItemsOutputIt>
-pair<KeysOutputIt, ItemsOutputIt> __host__ __device__
+pair<KeysOutputIt, ItemsOutputIt> _CCCL_HOST_DEVICE
 set_union_by_key(execution_policy<Derived> &policy,
                  KeysIt1                    keys1_first,
                  KeysIt1                    keys1_last,
