@@ -51,7 +51,7 @@ template <class Derived,
           class OutputIt,
           class TransformOp,
           class ScanOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 transform_inclusive_scan(execution_policy<Derived> &policy,
                          InputIt                    first,
                          InputIt                    last,
@@ -84,7 +84,7 @@ template <class Derived,
           class TransformOp,
           class InitialValueType,
           class ScanOp>
-OutputIt __host__ __device__
+OutputIt _CCCL_HOST_DEVICE
 transform_exclusive_scan(execution_policy<Derived> &policy,
                          InputIt                    first,
                          InputIt                    last,
