@@ -52,7 +52,7 @@
 THRUST_NAMESPACE_BEGIN
 namespace cuda_cub {
 
-inline __host__ __device__
+inline _CCCL_HOST_DEVICE
 cudaStream_t
 default_stream()
 {
@@ -65,7 +65,7 @@ default_stream()
 
 // Fallback implementation of the customization point.
 template <class Derived>
-__host__ __device__
+_CCCL_HOST_DEVICE
 cudaStream_t
 get_stream(execution_policy<Derived> &)
 {
@@ -74,7 +74,7 @@ get_stream(execution_policy<Derived> &)
 
 // Entry point/interface.
 template <class Derived>
-__host__ __device__ cudaStream_t
+_CCCL_HOST_DEVICE cudaStream_t
 stream(execution_policy<Derived> &policy)
 {
   return get_stream(derived_cast(policy));
@@ -83,7 +83,7 @@ stream(execution_policy<Derived> &policy)
 
 // Fallback implementation of the customization point.
 template <class Derived>
-__host__ __device__
+_CCCL_HOST_DEVICE
 bool
 must_perform_optional_stream_synchronization(execution_policy<Derived> &)
 {
@@ -92,7 +92,7 @@ must_perform_optional_stream_synchronization(execution_policy<Derived> &)
 
 // Entry point/interface.
 template <class Derived>
-__host__ __device__ bool
+_CCCL_HOST_DEVICE bool
 must_perform_optional_synchronization(execution_policy<Derived> &policy)
 {
   return must_perform_optional_stream_synchronization(derived_cast(policy));
@@ -100,9 +100,9 @@ must_perform_optional_synchronization(execution_policy<Derived> &policy)
 
 
 // Fallback implementation of the customization point.
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived>
-__host__ __device__
+_CCCL_HOST_DEVICE
 cudaError_t
 synchronize_stream(execution_policy<Derived> &policy)
 {
@@ -111,7 +111,7 @@ synchronize_stream(execution_policy<Derived> &policy)
 
 // Entry point/interface.
 template <class Policy>
-__host__ __device__
+_CCCL_HOST_DEVICE
 cudaError_t
 synchronize(Policy &policy)
 {
@@ -119,9 +119,9 @@ synchronize(Policy &policy)
 }
 
 // Fallback implementation of the customization point.
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template <class Derived>
-__host__ __device__
+_CCCL_HOST_DEVICE
 cudaError_t
 synchronize_stream_optional(execution_policy<Derived> &policy)
 {
@@ -141,7 +141,7 @@ synchronize_stream_optional(execution_policy<Derived> &policy)
 
 // Entry point/interface.
 template <class Policy>
-__host__ __device__
+_CCCL_HOST_DEVICE
 cudaError_t
 synchronize_optional(Policy &policy)
 {
@@ -187,7 +187,7 @@ trivial_copy_to_device(Type *       dst,
 }
 
 template <class Policy, class Type>
-__host__ __device__ cudaError_t
+_CCCL_HOST_DEVICE cudaError_t
 trivial_copy_device_to_device(Policy &    policy,
                               Type *      dst,
                               Type const *src,
@@ -207,13 +207,13 @@ trivial_copy_device_to_device(Policy &    policy,
   return status;
 }
 
-inline void __host__ __device__
+inline void _CCCL_HOST_DEVICE
 terminate()
 {
   NV_IF_TARGET(NV_IS_HOST, (std::terminate();), (asm("trap;");));
 }
 
-__host__  __device__
+_CCCL_HOST_DEVICE
 inline void throw_on_error(cudaError_t status)
 {
   // Clear the global CUDA error state which may have been set by the last
@@ -256,7 +256,7 @@ inline void throw_on_error(cudaError_t status)
   }
 }
 
-__host__ __device__
+_CCCL_HOST_DEVICE
 inline void throw_on_error(cudaError_t status, char const *msg)
 {
   // Clear the global CUDA error state which may have been set by the last
@@ -317,17 +317,17 @@ struct transform_input_iterator_t
   InputIt         input;
   mutable UnaryOp op;
 
-  __host__ __device__ __forceinline__
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE
   transform_input_iterator_t(InputIt input, UnaryOp op)
       : input(input), op(op) {}
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
   transform_input_iterator_t(const self_t &) = default;
 #endif
 
   // UnaryOp might not be copy assignable, such as when it is a lambda.  Define
   // an explicit copy assignment operator that doesn't try to assign it.
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   self_t& operator=(const self_t& o)
   {
     input = o.input;
@@ -335,7 +335,7 @@ struct transform_input_iterator_t
   }
 
   /// Postfix increment
-  __host__ __device__ __forceinline__ self_t operator++(int)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++(int)
   {
     self_t retval = *this;
     ++input;
@@ -343,71 +343,71 @@ struct transform_input_iterator_t
   }
 
   /// Prefix increment
-  __host__ __device__ __forceinline__ self_t operator++()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++()
   {
     ++input;
     return *this;
   }
 
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*() const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*() const
   {
     typename thrust::iterator_value<InputIt>::type x = *input;
     return op(x);
   }
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*()
   {
     typename thrust::iterator_value<InputIt>::type x = *input;
     return op(x);
   }
 
   /// Addition
-  __host__ __device__ __forceinline__ self_t operator+(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator+(difference_type n) const
   {
     return self_t(input + n, op);
   }
 
   /// Addition assignment
-  __host__ __device__ __forceinline__ self_t &operator+=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator+=(difference_type n)
   {
     input += n;
     return *this;
   }
 
   /// Subtraction
-  __host__ __device__ __forceinline__ self_t operator-(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator-(difference_type n) const
   {
     return self_t(input - n, op);
   }
 
   /// Subtraction assignment
-  __host__ __device__ __forceinline__ self_t &operator-=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator-=(difference_type n)
   {
     input -= n;
     return *this;
   }
 
   /// Distance
-  __host__ __device__ __forceinline__ difference_type operator-(self_t other) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE difference_type operator-(self_t other) const
   {
     return input - other.input;
   }
 
   /// Array subscript
-  __host__ __device__ __forceinline__ reference operator[](difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator[](difference_type n) const
   {
     return op(input[n]);
   }
 
   /// Equal to
-  __host__ __device__ __forceinline__ bool operator==(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator==(const self_t &rhs) const
   {
     return (input == rhs.input);
   }
 
   /// Not equal to
-  __host__ __device__ __forceinline__ bool operator!=(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator!=(const self_t &rhs) const
   {
     return (input != rhs.input);
   }
@@ -430,19 +430,19 @@ struct transform_pair_of_input_iterators_t
   InputIt2         input2;
   mutable BinaryOp op;
 
-  __host__ __device__ __forceinline__
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE
   transform_pair_of_input_iterators_t(InputIt1 input1_,
                                       InputIt2 input2_,
                                       BinaryOp op_)
       : input1(input1_), input2(input2_), op(op_) {}
 
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
   transform_pair_of_input_iterators_t(const self_t &) = default;
 #endif
 
   // BinaryOp might not be copy assignable, such as when it is a lambda.
   // Define an explicit copy assignment operator that doesn't try to assign it.
-  __host__ __device__
+  _CCCL_HOST_DEVICE
   self_t& operator=(const self_t& o)
   {
     input1 = o.input1;
@@ -451,7 +451,7 @@ struct transform_pair_of_input_iterators_t
   }
 
   /// Postfix increment
-  __host__ __device__ __forceinline__ self_t operator++(int)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++(int)
   {
     self_t retval = *this;
     ++input1;
@@ -460,7 +460,7 @@ struct transform_pair_of_input_iterators_t
   }
 
   /// Prefix increment
-  __host__ __device__ __forceinline__ self_t operator++()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++()
   {
     ++input1;
     ++input2;
@@ -468,24 +468,24 @@ struct transform_pair_of_input_iterators_t
   }
 
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*() const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*() const
   {
     return op(*input1, *input2);
   }
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*()
   {
     return op(*input1, *input2);
   }
 
   /// Addition
-  __host__ __device__ __forceinline__ self_t operator+(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator+(difference_type n) const
   {
     return self_t(input1 + n, input2 + n, op);
   }
 
   /// Addition assignment
-  __host__ __device__ __forceinline__ self_t &operator+=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator+=(difference_type n)
   {
     input1 += n;
     input2 += n;
@@ -493,13 +493,13 @@ struct transform_pair_of_input_iterators_t
   }
 
   /// Subtraction
-  __host__ __device__ __forceinline__ self_t operator-(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator-(difference_type n) const
   {
     return self_t(input1 - n, input2 - n, op);
   }
 
   /// Subtraction assignment
-  __host__ __device__ __forceinline__ self_t &operator-=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator-=(difference_type n)
   {
     input1 -= n;
     input2 -= n;
@@ -507,25 +507,25 @@ struct transform_pair_of_input_iterators_t
   }
 
   /// Distance
-  __host__ __device__ __forceinline__ difference_type operator-(self_t other) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE difference_type operator-(self_t other) const
   {
     return input1 - other.input1;
   }
 
   /// Array subscript
-  __host__ __device__ __forceinline__ reference operator[](difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator[](difference_type n) const
   {
     return op(input1[n], input2[n]);
   }
 
   /// Equal to
-  __host__ __device__ __forceinline__ bool operator==(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator==(const self_t &rhs) const
   {
     return (input1 == rhs.input1) && (input2 == rhs.input2);
   }
 
   /// Not equal to
-  __host__ __device__ __forceinline__ bool operator!=(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator!=(const self_t &rhs) const
   {
     return (input1 != rhs.input1) || (input2 != rhs.input2);
   }
@@ -536,14 +536,14 @@ struct transform_pair_of_input_iterators_t
 struct identity
 {
   template <class T>
-  __host__ __device__ T const &
+  _CCCL_HOST_DEVICE T const &
   operator()(T const &t) const
   {
     return t;
   }
 
   template <class T>
-  __host__ __device__ T &
+  _CCCL_HOST_DEVICE T &
   operator()(T &t) const
   {
     return t;
@@ -563,11 +563,11 @@ struct counting_iterator_t
 
   T count;
 
-  __host__ __device__ __forceinline__
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE
   counting_iterator_t(T count_) : count(count_) {}
 
   /// Postfix increment
-  __host__ __device__ __forceinline__ self_t operator++(int)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++(int)
   {
     self_t retval = *this;
     ++count;
@@ -575,70 +575,70 @@ struct counting_iterator_t
   }
 
   /// Prefix increment
-  __host__ __device__ __forceinline__ self_t operator++()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator++()
   {
     ++count;
     return *this;
   }
 
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*() const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*() const
   {
     return count;
   }
 
   /// Indirection
-  __host__ __device__ __forceinline__ reference operator*()
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator*()
   {
     return count;
   }
 
   /// Addition
-  __host__ __device__ __forceinline__ self_t operator+(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator+(difference_type n) const
   {
     return self_t(count + n);
   }
 
   /// Addition assignment
-  __host__ __device__ __forceinline__ self_t &operator+=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator+=(difference_type n)
   {
     count += n;
     return *this;
   }
 
   /// Subtraction
-  __host__ __device__ __forceinline__ self_t operator-(difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t operator-(difference_type n) const
   {
     return self_t(count - n);
   }
 
   /// Subtraction assignment
-  __host__ __device__ __forceinline__ self_t &operator-=(difference_type n)
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE self_t &operator-=(difference_type n)
   {
     count -= n;
     return *this;
   }
 
   /// Distance
-  __host__ __device__ __forceinline__ difference_type operator-(self_t other) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE difference_type operator-(self_t other) const
   {
     return count - other.count;
   }
 
   /// Array subscript
-  __host__ __device__ __forceinline__ reference operator[](difference_type n) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE reference operator[](difference_type n) const
   {
     return count + n;
   }
 
   /// Equal to
-  __host__ __device__ __forceinline__ bool operator==(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator==(const self_t &rhs) const
   {
     return (count == rhs.count);
   }
 
   /// Not equal to
-  __host__ __device__ __forceinline__ bool operator!=(const self_t &rhs) const
+  _CCCL_HOST_DEVICE _CCCL_FORCEINLINE bool operator!=(const self_t &rhs) const
   {
     return (count != rhs.count);
   }
