@@ -49,7 +49,7 @@ namespace cuda_cub
  *  \see cuda::free
  *  \see std::malloc
  */
-inline __host__ __device__ pointer<void> malloc(std::size_t n);
+inline _CCCL_HOST_DEVICE pointer<void> malloc(std::size_t n);
 
 /*! Allocates a typed area of memory available to Thrust's <tt>cuda</tt> system.
  *  \param n Number of elements to allocate.
@@ -62,7 +62,7 @@ inline __host__ __device__ pointer<void> malloc(std::size_t n);
  *  \see std::malloc
  */
 template <typename T>
-inline __host__ __device__ pointer<T> malloc(std::size_t n);
+inline _CCCL_HOST_DEVICE pointer<T> malloc(std::size_t n);
 
 /*! Deallocates an area of memory previously allocated by <tt>cuda::malloc</tt>.
  *  \param ptr A <tt>cuda::pointer<void></tt> pointing to the beginning of an area
@@ -70,7 +70,7 @@ inline __host__ __device__ pointer<T> malloc(std::size_t n);
  *  \see cuda::malloc
  *  \see std::free
  */
-inline __host__ __device__ void free(pointer<void> ptr);
+inline _CCCL_HOST_DEVICE void free(pointer<void> ptr);
 
 /*! \p cuda::allocator is the default allocator used by the \p cuda system's
  *  containers such as <tt>cuda::vector</tt> if no user-specified allocator is
