@@ -38,7 +38,7 @@ namespace generic
 
 template<typename DerivedPolicy,
          typename ForwardIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
 ForwardIterator unique(thrust::execution_policy<DerivedPolicy> &exec,
                        ForwardIterator first,
                        ForwardIterator last);
@@ -47,7 +47,7 @@ ForwardIterator unique(thrust::execution_policy<DerivedPolicy> &exec,
 template<typename DerivedPolicy,
          typename ForwardIterator,
          typename BinaryPredicate>
-__host__ __device__
+_CCCL_HOST_DEVICE
 ForwardIterator unique(thrust::execution_policy<DerivedPolicy> &exec,
                        ForwardIterator first,
                        ForwardIterator last,
@@ -57,7 +57,7 @@ ForwardIterator unique(thrust::execution_policy<DerivedPolicy> &exec,
 template<typename DerivedPolicy,
          typename InputIterator,
          typename OutputIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
 OutputIterator unique_copy(thrust::execution_policy<DerivedPolicy> &exec,
                            InputIterator first,
                            InputIterator last,
@@ -68,7 +68,7 @@ template<typename DerivedPolicy,
          typename InputIterator,
          typename OutputIterator,
          typename BinaryPredicate>
-__host__ __device__
+_CCCL_HOST_DEVICE
 OutputIterator unique_copy(thrust::execution_policy<DerivedPolicy> &exec,
                            InputIterator first,
                            InputIterator last,
@@ -78,7 +78,7 @@ OutputIterator unique_copy(thrust::execution_policy<DerivedPolicy> &exec,
 
 template<typename DerivedPolicy,
          typename ForwardIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
 typename thrust::iterator_traits<ForwardIterator>::difference_type
     unique_count(thrust::execution_policy<DerivedPolicy> &exec,
                  ForwardIterator first,
@@ -88,7 +88,7 @@ typename thrust::iterator_traits<ForwardIterator>::difference_type
 template<typename DerivedPolicy,
          typename ForwardIterator,
          typename BinaryPredicate>
-__host__ __device__
+_CCCL_HOST_DEVICE
 typename thrust::iterator_traits<ForwardIterator>::difference_type
     unique_count(thrust::execution_policy<DerivedPolicy> &exec,
                  ForwardIterator first,
