@@ -72,9 +72,9 @@ struct reference_is_assignable
 // introduce an iterator assign helper to deal with assignments from
 // a wrapped reference
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template<typename OutputIterator, typename InputIterator>
-inline __host__ __device__
+inline _CCCL_HOST_DEVICE
 typename thrust::detail::enable_if<
   reference_is_assignable<InputIterator,OutputIterator>::value
 >::type
@@ -84,9 +84,9 @@ iter_assign(OutputIterator dst, InputIterator src)
 }
 
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template<typename OutputIterator, typename InputIterator>
-inline __host__ __device__
+inline _CCCL_HOST_DEVICE
 typename thrust::detail::disable_if<
   reference_is_assignable<InputIterator,OutputIterator>::value
 >::type
@@ -102,10 +102,10 @@ iter_assign(OutputIterator dst, InputIterator src)
 } // end general_copy_detail
 
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template<typename InputIterator,
          typename OutputIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator general_copy(InputIterator first,
                               InputIterator last,
                               OutputIterator result)
@@ -113,7 +113,7 @@ __host__ __device__
   for(; first != last; ++first, ++result)
   {
     // gcc 4.2 crashes while instantiating iter_assign
-#if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC) && (THRUST_GCC_VERSION < 40300)
+#if defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION < 40300)
     *result = *first;
 #else
     general_copy_detail::iter_assign(result, first);
@@ -124,11 +124,11 @@ __host__ __device__
 } // end general_copy()
 
 
-__thrust_exec_check_disable__
+_CCCL_EXEC_CHECK_DISABLE
 template<typename InputIterator,
          typename Size,
          typename OutputIterator>
-__host__ __device__
+_CCCL_HOST_DEVICE
   OutputIterator general_copy_n(InputIterator first,
                                 Size n,
                                 OutputIterator result)
@@ -136,7 +136,7 @@ __host__ __device__
   for(; n > Size(0); ++first, ++result, --n)
   {
     // gcc 4.2 crashes while instantiating iter_assign
-#if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC) && (THRUST_GCC_VERSION < 40300)
+#if defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION < 40300)
     *result = *first;
 #else
     general_copy_detail::iter_assign(result, first);
