@@ -259,9 +259,9 @@ class error_code
     template <typename ErrorCodeEnum>
       error_code(ErrorCodeEnum e
 // XXX WAR msvc's problem with enable_if
-#if THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#if !defined(_CCCL_COMPILER_MSVC)
         , typename thrust::detail::enable_if<is_error_code_enum<ErrorCodeEnum>::value>::type * = 0
-#endif // THRUST_HOST_COMPILER_MSVC
+#endif // !_CCCL_COMPILER_MSVC
         );
 
     // [19.5.2.3] modifiers:
@@ -274,11 +274,11 @@ class error_code
      */
     template <typename ErrorCodeEnum>
 // XXX WAR msvc's problem with enable_if
-#if THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#if !defined(_CCCL_COMPILER_MSVC)
       typename thrust::detail::enable_if<is_error_code_enum<ErrorCodeEnum>::value, error_code>::type &
 #else
       error_code &
-#endif // THRUST_HOST_COMPILER_MSVC
+#endif // !_CCCL_COMPILER_MSVC
         operator=(ErrorCodeEnum e);
 
     /*! \post <tt>value() == 0</tt> and <tt>category() == system_category()</tt>.
@@ -375,9 +375,9 @@ class error_condition
     template<typename ErrorConditionEnum>
       error_condition(ErrorConditionEnum e
 // XXX WAR msvc's problem with enable_if
-#if THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#if !defined(_CCCL_COMPILER_MSVC)
         , typename thrust::detail::enable_if<is_error_condition_enum<ErrorConditionEnum>::value>::type * = 0
-#endif // THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#endif // !_CCCL_COMPILER_MSVC
                      );
 
     // [19.5.3.3] modifiers
@@ -398,11 +398,11 @@ class error_condition
      */
     template<typename ErrorConditionEnum>
 // XXX WAR msvc's problem with enable_if
-#if THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#if !defined(_CCCL_COMPILER_MSVC)
       typename thrust::detail::enable_if<is_error_condition_enum<ErrorConditionEnum>::value, error_condition>::type &
 #else
       error_condition &
-#endif // THRUST_HOST_COMPILER != THRUST_HOST_COMPILER_MSVC
+#endif // !_CCCL_COMPILER_MSVC
         operator=(ErrorConditionEnum e);
 
     /*! Clears this \p error_code object.
