@@ -48,18 +48,18 @@ THRUST_NAMESPACE_BEGIN
  *  otherwise.
  */
 template <typename T>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 using is_execution_policy =
 #else
 struct is_execution_policy :
 #endif
   detail::is_base_of<detail::execution_policy_marker, T>
-#if THRUST_CPP_DIALECT < 2011
+#if _CCCL_STD_VER < 2011
 {}
 #endif
 ;
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 /*! \brief <tt>constexpr bool</tt> that is \c true if \c T is an
  *  \a ExecutionPolicy and \c false otherwise.
  */
