@@ -73,18 +73,18 @@ struct is_operator_greater_function_object_impl;
  *  \see is_operator_plus_function_object
  */
 template <typename T>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 using is_operator_less_function_object =
 #else
 struct is_operator_less_function_object :
 #endif
   detail::is_operator_less_function_object_impl<T>
-#if THRUST_CPP_DIALECT < 2011
+#if _CCCL_STD_VER < 2011
 {}
 #endif
 ;
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 /*! \brief <tt>constexpr bool</tt> that is \c true if \c T is a
  *  <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>
  *  equivalent to \c operator<, and \c false otherwise.
@@ -110,18 +110,18 @@ constexpr bool is_operator_less_function_object_v
  *  \see is_operator_plus_function_object
  */
 template <typename T>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 using is_operator_greater_function_object =
 #else
 struct is_operator_greater_function_object :
 #endif
   detail::is_operator_greater_function_object_impl<T>
-#if THRUST_CPP_DIALECT < 2011
+#if _CCCL_STD_VER < 2011
 {}
 #endif
 ;
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 /*! \brief <tt>constexpr bool</tt> that is \c true if \c T is a
  *  <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>
  *  equivalent to \c operator>, and \c false otherwise.
@@ -147,7 +147,7 @@ constexpr bool is_operator_greater_function_object_v
  *  \see is_operator_plus_function_object
  */
 template <typename T>
-#if THRUST_CPP_DIALECT >= 2011
+#if _CCCL_STD_VER >= 2011
 using is_operator_less_or_greater_function_object =
 #else
 struct is_operator_less_or_greater_function_object :
@@ -157,12 +157,12 @@ struct is_operator_less_or_greater_function_object :
   ,    detail::is_operator_less_function_object_impl<T>::value
     || detail::is_operator_greater_function_object_impl<T>::value
   >
-#if THRUST_CPP_DIALECT < 2011
+#if _CCCL_STD_VER < 2011
 {}
 #endif
 ;
 
-#if THRUST_CPP_DIALECT >= 2014
+#if _CCCL_STD_VER >= 2014
 /*! \brief <tt>constexpr bool</tt> that is \c true if \c T is a
  *  <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>
  *  equivalent to \c operator< or \c operator>, and \c false otherwise.
